# Generated by asset_id_files.py

AGON_ENERGY_CONTROLLER_MREA = 0x02FC3717
AGON_MAP_STATION_MREA = 0x845C85A7
AGON_TEMPLE_MREA = 0x75FC9AAE
BATTLEGROUND_MREA = 0xEA79522C
BIOENERGY_PRODUCTION_MREA = 0x13470DA8
BIOSTORAGE_ACCESS_MREA = 0xDEEB1668
BIOSTORAGE_STATION_MREA = 0x80896CE9
BITTER_WELL_MREA = 0x04F1C1D8
CENTRAL_MINING_STATION_MREA = 0xF5A6D972
CENTRAL_STATION_ACCESS_MREA = 0xFE69E0C3
COMMAND_CENTER_MREA = 0x31C25557
COMMAND_CENTER_ACCESS_MREA = 0x708387F9
CONTROLLER_ACCESS_MREA = 0xBF5399C0
CROSSROADS_MREA = 0x8E23DB3F
DARK_AGON_ENERGY_CONTROLLER_MREA = 0xB7DD4006
DARK_AGON_TEMPLE_MREA = 0x7575048A
DARK_AGON_TEMPLE_ACCESS_MREA = 0x2103C8AE
DARK_CONTROLLER_ACCESS_MREA = 0xA2F347D1
DARK_OASIS_MREA = 0x99FB957F
DARK_TRANSIT_STATION_MREA = 0xD73ECD68
DOOMED_ENTRY_MREA = 0xA49F8A6D
DOUBLE_PATH_MREA = 0x7FEF433B
DUELLING_RANGE_MREA = 0x3F5CDF39
FEEDING_PIT_MREA = 0x075A76EB
FEEDING_PIT_ACCESS_MREA = 0xE035C0A5
HALL_OF_STAIRS_MREA = 0x6D164780
ING_CACHE_1_MREA = 0x52962FB6
ING_CACHE_2_MREA = 0x9318F076
ING_CACHE_3_MREA = 0xBA23E5F5
ING_CACHE_4_MREA = 0xC5C7C9D3
JUDGMENT_PIT_MREA = 0x6B77F9BD
JUNCTION_SITE_MREA = 0x1608C563
MAIN_ENERGY_CONTROLLER_MREA = 0xD92890C3
MAIN_REACTOR_MREA = 0xCCD9F39E
MINE_SHAFT_MREA = 0xD7A15431
MINING_PLAZA_MREA = 0x427FAD9A
MINING_STATION_A_MREA = 0xE3BEF27F
MINING_STATION_ACCESS_MREA = 0x8D7A7F8C
MINING_STATION_B_MREA = 0xDB7B2CED
OASIS_ACCESS_MREA = 0xF2CCC41E
PHAZON_SITE_MREA = 0x200EF5E7
PLAZA_ACCESS_MREA = 0xADF88927
PORTAL_ACCESS_MREA = 0x89D246FD
PORTAL_ACCESS_A_MREA = 0x2312EE1D
PORTAL_SITE_MREA = 0xBF7F572C
PORTAL_TERMINAL_MREA = 0x2BCD44A7
SAND_CACHE_MREA = 0xF4B1F727
SAND_PROCESSING_MREA = 0xA4B2CB7E
SANDCANYON_MREA = 0xE5B72628
SAVE_STATION_1_MREA = 0x5A154E2E
SAVE_STATION_2_MREA = 0xAC204F8B
SAVE_STATION_3_MREA = 0x0279F7EF
SAVE_STATION_A_MREA = 0x50017152
SAVE_STATION_C_MREA = 0xB979562C
SECURITY_STATION_A_MREA = 0xF723A29A
SECURITY_STATION_B_MREA = 0x0ADA5AEF
STORAGE_A_MREA = 0x10323944
STORAGE_B_MREA = 0x96A64BEA
STORAGE_C_MREA = 0x5DFA984F
STORAGE_D_MREA = 0x40FFA8F7
TEMPLE_ACCESS_MREA = 0x2A58AC44
TRANSIT_STATION_MREA = 0x79C9C5A0
TRANSPORT_CENTER_MREA = 0x4BDFB7B9
TRANSPORT_TO_SANCTUARY_FORTRESS_MREA = 0xC68B5B51
TRANSPORT_TO_TEMPLE_GROUNDS_MREA = 0x57CE3A52
TRANSPORT_TO_TORVUS_BOG_MREA = 0xA74EC002
TRIAL_GROUNDS_MREA = 0x86C1AB37
TRIAL_TUNNEL_MREA = 0x48E44EF6
VENTILATION_AREA_A_MREA = 0x84303DD5
VENTILATION_AREA_B_MREA = 0x594B330B
WARRIORS_WALK_MREA = 0x33FACC15
WATERING_HOLE_MREA = 0x9B2B4246

NAME_TO_ID_MREA = {
    "Agon Energy Controller": 0x02FC3717,
    "Agon Map Station": 0x845C85A7,
    "Agon Temple": 0x75FC9AAE,
    "Battleground": 0xEA79522C,
    "Bioenergy Production": 0x13470DA8,
    "Biostorage Access": 0xDEEB1668,
    "Biostorage Station": 0x80896CE9,
    "Bitter Well": 0x04F1C1D8,
    "Central Mining Station": 0xF5A6D972,
    "Central Station Access": 0xFE69E0C3,
    "Command Center": 0x31C25557,
    "Command Center Access": 0x708387F9,
    "Controller Access": 0xBF5399C0,
    "Crossroads": 0x8E23DB3F,
    "Dark Agon Energy Controller": 0xB7DD4006,
    "Dark Agon Temple": 0x7575048A,
    "Dark Agon Temple Access": 0x2103C8AE,
    "Dark Controller Access": 0xA2F347D1,
    "Dark Oasis": 0x99FB957F,
    "Dark Transit Station": 0xD73ECD68,
    "Doomed Entry": 0xA49F8A6D,
    "Double Path": 0x7FEF433B,
    "Duelling Range": 0x3F5CDF39,
    "Feeding Pit": 0x075A76EB,
    "Feeding Pit Access": 0xE035C0A5,
    "Hall of Stairs": 0x6D164780,
    "Ing Cache 1": 0x52962FB6,
    "Ing Cache 2": 0x9318F076,
    "Ing Cache 3": 0xBA23E5F5,
    "Ing Cache 4": 0xC5C7C9D3,
    "Judgment Pit": 0x6B77F9BD,
    "Junction Site": 0x1608C563,
    "Main Energy Controller": 0xD92890C3,
    "Main Reactor": 0xCCD9F39E,
    "Mine Shaft": 0xD7A15431,
    "Mining Plaza": 0x427FAD9A,
    "Mining Station A": 0xE3BEF27F,
    "Mining Station Access": 0x8D7A7F8C,
    "Mining Station B": 0xDB7B2CED,
    "Oasis Access": 0xF2CCC41E,
    "Phazon Site": 0x200EF5E7,
    "Plaza Access": 0xADF88927,
    "Portal Access": 0x89D246FD,
    "Portal Access A": 0x2312EE1D,
    "Portal Site": 0xBF7F572C,
    "Portal Terminal": 0x2BCD44A7,
    "Sand Cache": 0xF4B1F727,
    "Sand Processing": 0xA4B2CB7E,
    "Sandcanyon": 0xE5B72628,
    "Save Station 1": 0x5A154E2E,
    "Save Station 2": 0xAC204F8B,
    "Save Station 3": 0x0279F7EF,
    "Save Station A": 0x50017152,
    "Save Station C": 0xB979562C,
    "Security Station A": 0xF723A29A,
    "Security Station B": 0x0ADA5AEF,
    "Storage A": 0x10323944,
    "Storage B": 0x96A64BEA,
    "Storage C": 0x5DFA984F,
    "Storage D": 0x40FFA8F7,
    "Temple Access": 0x2A58AC44,
    "Transit Station": 0x79C9C5A0,
    "Transport Center": 0x4BDFB7B9,
    "Transport to Sanctuary Fortress": 0xC68B5B51,
    "Transport to Temple Grounds": 0x57CE3A52,
    "Transport to Torvus Bog": 0xA74EC002,
    "Trial Grounds": 0x86C1AB37,
    "Trial Tunnel": 0x48E44EF6,
    "Ventilation Area A": 0x84303DD5,
    "Ventilation Area B": 0x594B330B,
    "Warrior's Walk": 0x33FACC15,
    "Watering Hole": 0x9B2B4246,
}
# Generated by asset_id_files.py

AGON_ENERGY_CONTROLLER_MAPA = 0x2B29CC2A
AGON_MAP_STATION_MAPA = 0xAD897E9A
AGON_TEMPLE_MAPA = 0x5C296193
BATTLEGROUND_MAPA = 0xC3ACA911
BIOENERGY_PRODUCTION_MAPA = 0x3A92F695
BIOSTORAGE_ACCESS_MAPA = 0xF73EED55
BIOSTORAGE_STATION_MAPA = 0xA95C97D4
BITTER_WELL_MAPA = 0x2D243AE5
CENTRAL_MINING_STATION_MAPA = 0xDC73224F
CENTRAL_STATION_ACCESS_MAPA = 0xD7BC1BFE
COMMAND_CENTER_MAPA = 0x1817AE6A
COMMAND_CENTER_ACCESS_MAPA = 0x59567CC4
CONTROLLER_ACCESS_MAPA = 0x968662FD
CROSSROADS_MAPA = 0xA7F62002
DARK_AGON_ENERGY_CONTROLLER_MAPA = 0x9E08BB3B
DARK_AGON_TEMPLE_MAPA = 0x5CA0FFB7
DARK_AGON_TEMPLE_ACCESS_MAPA = 0x08D63393
DARK_CONTROLLER_ACCESS_MAPA = 0x8B26BCEC
DARK_OASIS_MAPA = 0xB02E6E42
DARK_TRANSIT_STATION_MAPA = 0xFEEB3655
DOOMED_ENTRY_MAPA = 0x8D4A7150
DOUBLE_PATH_MAPA = 0x563AB806
DUELLING_RANGE_MAPA = 0x16892404
FEEDING_PIT_MAPA = 0x2E8F8DD6
FEEDING_PIT_ACCESS_MAPA = 0xC9E03B98
HALL_OF_STAIRS_MAPA = 0x44C3BCBD
ING_CACHE_1_MAPA = 0x7B43D48B
ING_CACHE_2_MAPA = 0xBACD0B4B
ING_CACHE_3_MAPA = 0x93F61EC8
ING_CACHE_4_MAPA = 0xEC1232EE
JUDGMENT_PIT_MAPA = 0x42A20280
JUNCTION_SITE_MAPA = 0x3FDD3E5E
MAIN_ENERGY_CONTROLLER_MAPA = 0xF0FD6BFE
MAIN_REACTOR_MAPA = 0xE50C08A3
MINE_SHAFT_MAPA = 0xFE74AF0C
MINING_PLAZA_MAPA = 0x6BAA56A7
MINING_STATION_A_MAPA = 0xCA6B0942
MINING_STATION_ACCESS_MAPA = 0xA4AF84B1
MINING_STATION_B_MAPA = 0xF2AED7D0
OASIS_ACCESS_MAPA = 0xDB193F23
PHAZON_SITE_MAPA = 0x09DB0EDA
PLAZA_ACCESS_MAPA = 0x842D721A
PORTAL_ACCESS_MAPA = 0xA007BDC0
PORTAL_ACCESS_A_MAPA = 0x0AC71520
PORTAL_SITE_MAPA = 0x96AAAC11
PORTAL_TERMINAL_MAPA = 0x0218BF9A
SAND_CACHE_MAPA = 0xDD640C1A
SAND_PROCESSING_MAPA = 0x8D673043
SANDCANYON_MAPA = 0xCC62DD15
SAVE_STATION_1_MAPA = 0x73C0B513
SAVE_STATION_2_MAPA = 0x85F5B4B6
SAVE_STATION_3_MAPA = 0x2BAC0CD2
SAVE_STATION_A_MAPA = 0x79D48A6F
SAVE_STATION_C_MAPA = 0x90ACAD11
SECURITY_STATION_A_MAPA = 0xDEF659A7
SECURITY_STATION_B_MAPA = 0x230FA1D2
STORAGE_A_MAPA = 0x39E7C279
STORAGE_B_MAPA = 0xBF73B0D7
STORAGE_C_MAPA = 0x742F6372
STORAGE_D_MAPA = 0x692A53CA
TEMPLE_ACCESS_MAPA = 0x038D5779
TRANSIT_STATION_MAPA = 0x501C3E9D
TRANSPORT_CENTER_MAPA = 0x620A4C84
TRANSPORT_TO_SANCTUARY_FORTRESS_MAPA = 0xEF5EA06C
TRANSPORT_TO_TEMPLE_GROUNDS_MAPA = 0x7E1BC16F
TRANSPORT_TO_TORVUS_BOG_MAPA = 0x8E9B3B3F
TRIAL_GROUNDS_MAPA = 0xAF14500A
TRIAL_TUNNEL_MAPA = 0x6131B5CB
VENTILATION_AREA_A_MAPA = 0xADE5C6E8
VENTILATION_AREA_B_MAPA = 0x709EC836
WARRIORS_WALK_MAPA = 0x1A2F3728
WATERING_HOLE_MAPA = 0xB2FEB97B

NAME_TO_ID_MAPA = {
    "Agon Energy Controller": 0x2B29CC2A,
    "Agon Map Station": 0xAD897E9A,
    "Agon Temple": 0x5C296193,
    "Battleground": 0xC3ACA911,
    "Bioenergy Production": 0x3A92F695,
    "Biostorage Access": 0xF73EED55,
    "Biostorage Station": 0xA95C97D4,
    "Bitter Well": 0x2D243AE5,
    "Central Mining Station": 0xDC73224F,
    "Central Station Access": 0xD7BC1BFE,
    "Command Center": 0x1817AE6A,
    "Command Center Access": 0x59567CC4,
    "Controller Access": 0x968662FD,
    "Crossroads": 0xA7F62002,
    "Dark Agon Energy Controller": 0x9E08BB3B,
    "Dark Agon Temple": 0x5CA0FFB7,
    "Dark Agon Temple Access": 0x08D63393,
    "Dark Controller Access": 0x8B26BCEC,
    "Dark Oasis": 0xB02E6E42,
    "Dark Transit Station": 0xFEEB3655,
    "Doomed Entry": 0x8D4A7150,
    "Double Path": 0x563AB806,
    "Duelling Range": 0x16892404,
    "Feeding Pit": 0x2E8F8DD6,
    "Feeding Pit Access": 0xC9E03B98,
    "Hall of Stairs": 0x44C3BCBD,
    "Ing Cache 1": 0x7B43D48B,
    "Ing Cache 2": 0xBACD0B4B,
    "Ing Cache 3": 0x93F61EC8,
    "Ing Cache 4": 0xEC1232EE,
    "Judgment Pit": 0x42A20280,
    "Junction Site": 0x3FDD3E5E,
    "Main Energy Controller": 0xF0FD6BFE,
    "Main Reactor": 0xE50C08A3,
    "Mine Shaft": 0xFE74AF0C,
    "Mining Plaza": 0x6BAA56A7,
    "Mining Station A": 0xCA6B0942,
    "Mining Station Access": 0xA4AF84B1,
    "Mining Station B": 0xF2AED7D0,
    "Oasis Access": 0xDB193F23,
    "Phazon Site": 0x09DB0EDA,
    "Plaza Access": 0x842D721A,
    "Portal Access": 0xA007BDC0,
    "Portal Access A": 0x0AC71520,
    "Portal Site": 0x96AAAC11,
    "Portal Terminal": 0x0218BF9A,
    "Sand Cache": 0xDD640C1A,
    "Sand Processing": 0x8D673043,
    "Sandcanyon": 0xCC62DD15,
    "Save Station 1": 0x73C0B513,
    "Save Station 2": 0x85F5B4B6,
    "Save Station 3": 0x2BAC0CD2,
    "Save Station A": 0x79D48A6F,
    "Save Station C": 0x90ACAD11,
    "Security Station A": 0xDEF659A7,
    "Security Station B": 0x230FA1D2,
    "Storage A": 0x39E7C279,
    "Storage B": 0xBF73B0D7,
    "Storage C": 0x742F6372,
    "Storage D": 0x692A53CA,
    "Temple Access": 0x038D5779,
    "Transit Station": 0x501C3E9D,
    "Transport Center": 0x620A4C84,
    "Transport to Sanctuary Fortress": 0xEF5EA06C,
    "Transport to Temple Grounds": 0x7E1BC16F,
    "Transport to Torvus Bog": 0x8E9B3B3F,
    "Trial Grounds": 0xAF14500A,
    "Trial Tunnel": 0x6131B5CB,
    "Ventilation Area A": 0xADE5C6E8,
    "Ventilation Area B": 0x709EC836,
    "Warrior's Walk": 0x1A2F3728,
    "Watering Hole": 0xB2FEB97B,
}
# Generated by asset_id_files.py

AGON_ENERGY_CONTROLLER_INTERNAL_ID = 0xE250F791
AGON_MAP_STATION_INTERNAL_ID = 0x538BF04F
AGON_TEMPLE_INTERNAL_ID = 0xE13DA78B
BATTLEGROUND_INTERNAL_ID = 0xC307E36F
BIOENERGY_PRODUCTION_INTERNAL_ID = 0x7D231C5D
BIOSTORAGE_ACCESS_INTERNAL_ID = 0x4ECF9934
BIOSTORAGE_STATION_INTERNAL_ID = 0x7C8E5C4D
BITTER_WELL_INTERNAL_ID = 0xAC9DB4AE
CENTRAL_MINING_STATION_INTERNAL_ID = 0xD16D7648
CENTRAL_STATION_ACCESS_INTERNAL_ID = 0xABAF67E7
COMMAND_CENTER_INTERNAL_ID = 0xAA657163
COMMAND_CENTER_ACCESS_INTERNAL_ID = 0xF681BFC1
CONTROLLER_ACCESS_INTERNAL_ID = 0x4B685014
CROSSROADS_INTERNAL_ID = 0xD9FD4BCB
DARK_AGON_ENERGY_CONTROLLER_INTERNAL_ID = 0xEF855B84
DARK_AGON_TEMPLE_INTERNAL_ID = 0x8DE34ED5
DARK_AGON_TEMPLE_ACCESS_INTERNAL_ID = 0x8627988A
DARK_CONTROLLER_ACCESS_INTERNAL_ID = 0x350DAA91
DARK_OASIS_INTERNAL_ID = 0xD5B16346
DARK_TRANSIT_STATION_INTERNAL_ID = 0x99D40591
DOOMED_ENTRY_INTERNAL_ID = 0x9244D4D5
DOUBLE_PATH_INTERNAL_ID = 0x4EDCF903
DUELLING_RANGE_INTERNAL_ID = 0x1BA88A01
FEEDING_PIT_INTERNAL_ID = 0x2B9333CF
FEEDING_PIT_ACCESS_INTERNAL_ID = 0xA6333FA7
HALL_OF_STAIRS_INTERNAL_ID = 0x5B81EF11
ING_CACHE_1_INTERNAL_ID = 0x6845CF3A
ING_CACHE_2_INTERNAL_ID = 0x765DA1AE
ING_CACHE_3_INTERNAL_ID = 0x2C14A842
ING_CACHE_4_INTERNAL_ID = 0x8C891383
JUDGMENT_PIT_INTERNAL_ID = 0x2BB2B2D4
JUNCTION_SITE_INTERNAL_ID = 0xB9C0A2BC
MAIN_ENERGY_CONTROLLER_INTERNAL_ID = 0x9C550062
MAIN_REACTOR_INTERNAL_ID = 0x80CBA3E1
MINE_SHAFT_INTERNAL_ID = 0xB80C0AB9
MINING_PLAZA_INTERNAL_ID = 0xC6102F1B
MINING_STATION_A_INTERNAL_ID = 0xC3FE1203
MINING_STATION_ACCESS_INTERNAL_ID = 0x69894388
MINING_STATION_B_INTERNAL_ID = 0x3A9B7C8D
OASIS_ACCESS_INTERNAL_ID = 0xB36E29B5
PHAZON_SITE_INTERNAL_ID = 0x3AC464B1
PLAZA_ACCESS_INTERNAL_ID = 0x8CE9BD5B
PORTAL_ACCESS_INTERNAL_ID = 0x512F6418
PORTAL_ACCESS_A_INTERNAL_ID = 0xD1C7657D
PORTAL_SITE_INTERNAL_ID = 0x3EFE8B8D
PORTAL_TERMINAL_INTERNAL_ID = 0x9ECAA95E
SAND_CACHE_INTERNAL_ID = 0x6E1F159C
SAND_PROCESSING_INTERNAL_ID = 0x7A2A2ED6
SANDCANYON_INTERNAL_ID = 0x6B9AD531
SAVE_STATION_1_INTERNAL_ID = 0x951030E9
SAVE_STATION_2_INTERNAL_ID = 0x7B95483C
SAVE_STATION_3_INTERNAL_ID = 0xE92426C4
SAVE_STATION_A_INTERNAL_ID = 0x13E14112
SAVE_STATION_C_INTERNAL_ID = 0xDE113070
SECURITY_STATION_A_INTERNAL_ID = 0x5D6CF46A
SECURITY_STATION_B_INTERNAL_ID = 0xC2640823
STORAGE_A_INTERNAL_ID = 0x484C1B94
STORAGE_B_INTERNAL_ID = 0x3694CC04
STORAGE_C_INTERNAL_ID = 0x1CDC8174
STORAGE_D_INTERNAL_ID = 0xCB256324
TEMPLE_ACCESS_INTERNAL_ID = 0x2704F6F0
TRANSIT_STATION_INTERNAL_ID = 0x00422C4C
TRANSPORT_CENTER_INTERNAL_ID = 0xD3D4F3C4
TRANSPORT_TO_SANCTUARY_FORTRESS_INTERNAL_ID = 0xE6B9F017
TRANSPORT_TO_TEMPLE_GROUNDS_INTERNAL_ID = 0x0B3919B6
TRANSPORT_TO_TORVUS_BOG_INTERNAL_ID = 0x15B1250D
TRIAL_GROUNDS_INTERNAL_ID = 0x47B6E9D0
TRIAL_TUNNEL_INTERNAL_ID = 0x713BC335
VENTILATION_AREA_A_INTERNAL_ID = 0x9F4AD005
VENTILATION_AREA_B_INTERNAL_ID = 0xE522D29F
WARRIORS_WALK_INTERNAL_ID = 0x937A8E98
WATERING_HOLE_INTERNAL_ID = 0x4472720A

NAME_TO_ID_INTERNAL_ID = {
    "Agon Energy Controller": 0xE250F791,
    "Agon Map Station": 0x538BF04F,
    "Agon Temple": 0xE13DA78B,
    "Battleground": 0xC307E36F,
    "Bioenergy Production": 0x7D231C5D,
    "Biostorage Access": 0x4ECF9934,
    "Biostorage Station": 0x7C8E5C4D,
    "Bitter Well": 0xAC9DB4AE,
    "Central Mining Station": 0xD16D7648,
    "Central Station Access": 0xABAF67E7,
    "Command Center": 0xAA657163,
    "Command Center Access": 0xF681BFC1,
    "Controller Access": 0x4B685014,
    "Crossroads": 0xD9FD4BCB,
    "Dark Agon Energy Controller": 0xEF855B84,
    "Dark Agon Temple": 0x8DE34ED5,
    "Dark Agon Temple Access": 0x8627988A,
    "Dark Controller Access": 0x350DAA91,
    "Dark Oasis": 0xD5B16346,
    "Dark Transit Station": 0x99D40591,
    "Doomed Entry": 0x9244D4D5,
    "Double Path": 0x4EDCF903,
    "Duelling Range": 0x1BA88A01,
    "Feeding Pit": 0x2B9333CF,
    "Feeding Pit Access": 0xA6333FA7,
    "Hall of Stairs": 0x5B81EF11,
    "Ing Cache 1": 0x6845CF3A,
    "Ing Cache 2": 0x765DA1AE,
    "Ing Cache 3": 0x2C14A842,
    "Ing Cache 4": 0x8C891383,
    "Judgment Pit": 0x2BB2B2D4,
    "Junction Site": 0xB9C0A2BC,
    "Main Energy Controller": 0x9C550062,
    "Main Reactor": 0x80CBA3E1,
    "Mine Shaft": 0xB80C0AB9,
    "Mining Plaza": 0xC6102F1B,
    "Mining Station A": 0xC3FE1203,
    "Mining Station Access": 0x69894388,
    "Mining Station B": 0x3A9B7C8D,
    "Oasis Access": 0xB36E29B5,
    "Phazon Site": 0x3AC464B1,
    "Plaza Access": 0x8CE9BD5B,
    "Portal Access": 0x512F6418,
    "Portal Access A": 0xD1C7657D,
    "Portal Site": 0x3EFE8B8D,
    "Portal Terminal": 0x9ECAA95E,
    "Sand Cache": 0x6E1F159C,
    "Sand Processing": 0x7A2A2ED6,
    "Sandcanyon": 0x6B9AD531,
    "Save Station 1": 0x951030E9,
    "Save Station 2": 0x7B95483C,
    "Save Station 3": 0xE92426C4,
    "Save Station A": 0x13E14112,
    "Save Station C": 0xDE113070,
    "Security Station A": 0x5D6CF46A,
    "Security Station B": 0xC2640823,
    "Storage A": 0x484C1B94,
    "Storage B": 0x3694CC04,
    "Storage C": 0x1CDC8174,
    "Storage D": 0xCB256324,
    "Temple Access": 0x2704F6F0,
    "Transit Station": 0x00422C4C,
    "Transport Center": 0xD3D4F3C4,
    "Transport to Sanctuary Fortress": 0xE6B9F017,
    "Transport to Temple Grounds": 0x0B3919B6,
    "Transport to Torvus Bog": 0x15B1250D,
    "Trial Grounds": 0x47B6E9D0,
    "Trial Tunnel": 0x713BC335,
    "Ventilation Area A": 0x9F4AD005,
    "Ventilation Area B": 0xE522D29F,
    "Warrior's Walk": 0x937A8E98,
    "Watering Hole": 0x4472720A,
}

DOCK_NAMES = {
    "Agon Energy Controller": {
        "South": 0,
        "North1 (to 08 Copy)": 1,
    },
    "Agon Map Station": {
        "South": 0,
    },
    "Agon Temple": {
        "West": 0,
        "North": 1,
        "East": 2,
        "South": 3,
    },
    "Battleground": {
        "East_Lower": 0,
        "East_Upper": 1,
        "West": 2,
    },
    "Bioenergy Production": {
        "South": 0,
        "North": 1,
        "East": 2,
    },
    "Biostorage Access": {
        "South": 0,
        "North": 1,
    },
    "Biostorage Station": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Bitter Well": {
        "South": 0,
        "North": 1,
    },
    "Central Mining Station": {
        "East_Lower": 0,
        "East_Upper": 1,
        "West": 2,
    },
    "Central Station Access": {
        "West": 0,
        "East": 1,
    },
    "Command Center": {
        "WestLowerDoor": 0,
        "South": 1,
        "North": 2,
        "NorthObservation": 3,
        "WestUpperDoor": 4,
        "WestMorphballTunnel": 5,
        "VirtualNorth": 6,
    },
    "Command Center Access": {
        "EastLowerDoor": 0,
        "EastUpperDoor": 1,
        "EastMorphballTunnel": 2,
        "West_Upper": 3,
        "West_Lower": 4,
    },
    "Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Crossroads": {
        "West": 0,
        "East": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Dark Agon Energy Controller": {
        "South": 0,
        "North1": 1,
    },
    "Dark Agon Temple": {
        "West": 0,
        "North": 1,
        "East": 2,
        "South": 3,
    },
    "Dark Agon Temple Access": {
        "North": 0,
        "South": 1,
    },
    "Dark Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Dark Oasis": {
        "East_TopSouth": 0,
        "West_TopSouth": 1,
        "West_TopNorth": 2,
        "South1": 3,
        "VirtualEast": 4,
    },
    "Dark Transit Station": {
        "East": 0,
        "South": 1,
    },
    "Doomed Entry": {
        "WestLowerDoor": 0,
        "South": 1,
        "NorthObservation": 2,
        "WestUpperDoor": 3,
        "VirtualNorth": 4,
    },
    "Double Path": {
        "EastLowerDoor": 0,
        "EastUpperDoor": 1,
        "EastMorphballTunnel": 2,
        "West_Upper": 3,
        "West_Lower": 4,
    },
    "Duelling Range": {
        "North": 0,
        "South": 1,
        "West": 2,
        "East": 3,
        "VirtualDock": 4,
    },
    "Feeding Pit": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Feeding Pit Access": {
        "South": 0,
        "North": 1,
    },
    "Hall of Stairs": {
        "East": 0,
        "West": 1,
    },
    "Ing Cache 1": {
        "East": 0,
    },
    "Ing Cache 2": {
        "West": 0,
    },
    "Ing Cache 3": {
        "East": 0,
    },
    "Ing Cache 4": {
        "West": 0,
        "East": 1,
    },
    "Judgment Pit": {
        "North": 0,
        "East1": 1,
        "South_save": 2,
        "West1": 3,
        "South1": 4,
    },
    "Junction Site": {
        "East": 0,
        "West": 1,
    },
    "Main Energy Controller": {
        "SouthLight1": 0,
        "VirtualNorth": 1,
        "North1 (to 00 Sand Generator)": 2,
    },
    "Main Reactor": {
        "East_TopSouth": 0,
        "West_TopSouth": 1,
        "West_TopNorth": 2,
        "Docks_Docks_Docks_South": 3,
        "VirtualEast": 4,
    },
    "Mine Shaft": {
        "West": 0,
        "East": 1,
    },
    "Mining Plaza": {
        "NorthMap": 0,
        "North": 1,
        "South": 2,
        "West": 3,
        "East1": 4,
        "VirtualDock": 5,
    },
    "Mining Station A": {
        "North": 0,
        "East1": 1,
        "South_save": 2,
        "West1": 3,
        "South1": 4,
    },
    "Mining Station Access": {
        "East": 0,
        "West": 1,
    },
    "Mining Station B": {
        "Docks_SouthLower": 0,
        "East": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Oasis Access": {
        "South": 0,
        "South_Observation": 1,
        "North": 2,
    },
    "Phazon Site": {
        "South": 0,
        "North": 1,
        "East": 2,
    },
    "Plaza Access": {
        "West": 0,
        "East": 1,
    },
    "Portal Access": {
        "South": 0,
        "North": 1,
    },
    "Portal Access A": {
        "South": 0,
        "North": 1,
    },
    "Portal Site": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Portal Terminal": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Sand Cache": {
        "North": 0,
    },
    "Sand Processing": {
        "East": 0,
        "West": 1,
    },
    "Sandcanyon": {
        "West": 0,
        "East": 1,
    },
    "Save Station 1": {
        "North": 0,
    },
    "Save Station 2": {
        "North": 0,
        "East": 1,
    },
    "Save Station 3": {
        "South": 0,
        "West": 1,
    },
    "Save Station A": {
        "North": 0,
        "East": 1,
    },
    "Save Station C": {
        "South": 0,
        "West": 1,
    },
    "Security Station A": {
        "West": 0,
        "North": 1,
    },
    "Security Station B": {
        "South": 0,
        "South_Observation": 1,
        "North": 2,
    },
    "Storage A": {
        "North": 0,
    },
    "Storage B": {
        "East": 0,
    },
    "Storage C": {
        "West": 0,
    },
    "Storage D": {
        "East": 0,
    },
    "Temple Access": {
        "North": 0,
        "South": 1,
    },
    "Transit Station": {
        "East": 0,
        "South": 1,
    },
    "Transport Center": {
        "West": 0,
        "East": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Transport to Sanctuary Fortress": {
        "Dock - South": 0,
    },
    "Transport to Temple Grounds": {
        "East": 0,
    },
    "Transport to Torvus Bog": {
        "Dock - North": 0,
    },
    "Trial Grounds": {
        "Docks_SouthLower": 0,
        "East": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Trial Tunnel": {
        "West": 0,
        "East": 1,
    },
    "Ventilation Area A": {
        "docks_North": 0,
        "docks_docks_East": 1,
        "docks_West": 2,
    },
    "Ventilation Area B": {
        "South": 0,
        "North": 1,
    },
    "Warrior's Walk": {
        "West": 0,
        "East": 1,
    },
    "Watering Hole": {
        "West": 0,
        "North": 1,
    },
}
