TG_PAIRS = [
    # 01_temple_landingsite (Landing Site / Defiled Shrine)
    (0x62B0D67D, 0x16E116B4),
    # 0q_temple_hall (Service Access / Shrine Access)
    (0x9FB7503C, 0x1F1D07DF),
    # 0t_temple_hall (Path of Honor / Gateway Access)
    (0x7B4D31DB, 0x84324C98),
    # 09_temple_thirdleg (Meeting Grounds / War Ritual Grounds)
    (0x9B5EFA75, 0xAA77EAAD),
    # 12_temple_finalgate (Hall of Honored Dead / Sky Temple Gateway)
    (0xB8B34634, 0x87D35EE4),
    # 0n_temple_hall (Hall of Eyes / Base Access)
    (0x476BA84C, 0x686F5A1B),
    # 02_temple_exploration (Industrial Site / Accursed Lake)
    (0x62AC8AC4, 0x9FD196DF),
    # 10_temple_pathofeyes (Path of Eyes / Abandoned Base)
    (0xEE4732BE, 0xC6F4E0C2),
    # 0b_temple_hall (Collapsed Tunnel / Lake Access)
    (0x5B92D146, 0x688AB8AE),
    # 01_temple_hive03 (Hive Chamber B / Portal Site)
    (0x1D7BD3AE, 0xDA37FF97),
    # 03_temple_combattraining (Temple Assembly Site / Plain of Dark Worship)
    (0x4B4E5911, 0x0405EBA4),
    # 11_temple_grandpuzzle (Grand Windchamber / Ing Windchamber)
    (0xAD70917D, 0xCDEF2BF1),
    # 04_temple_unknownenemies (Communication Area / Reliquary Grounds)
    (0x635E8DA1, 0xFC8FC0A4),
    # 05_temple_federationsite (GFMC Compound / Phazon Grounds)
    (0x57757AD5, 0x645EF243),
    # 00_pickup_temple_a (Storage Cavern A / Ing Reliquary)
    (0x3800CF82, 0x749E82E3),
    # 0d_temple_hall (Trooper Security Station / Reliquary Access)
    (0x55EE6DC3, 0x8540CAD4),
    # 0e_temple_hall (Sacred Bridge / Phazon Pit)
    (0xBABCDB22, 0x1E332000),
    # 06_temple_sacredpath (Sacred Path / Profane Path)
    (0xC23CFFBD, 0x64E640D6),
]

AGON_PAIRS = [
    # 0a_sand_hall (Plaza Access / Ing Cache 4)
    (0xADF88927, 0xC5C7C9D3),
    # 01_sand_entrance (Mining Plaza / Duelling Range)
    (0x427FAD9A, 0x3F5CDF39),
    # 0e_sand_hall (Transit Station / Dark Transit Station)
    (0x79C9C5A0, 0xD73ECD68),
    # 0f_sand_hall (Save Station A / Save Station 2)
    (0x50017152, 0xAC204F8B),
    # 0o_sand_hall (Mining Station Access / Junction Site)
    (0x8D7A7F8C, 0x1608C563),
    # 04_sand_mining (Mining Station B / Trial Grounds)
    (0xDB7B2CED, 0x86C1AB37),
    # 0q_sand_hall (Transport Center / Crossroads)
    (0x4BDFB7B9, 0x8E23DB3F),
    # 02_sand_sandfalls (Mining Station A / Judgment Pit)
    (0xE3BEF27F, 0x6B77F9BD),
    # 0d_sand_hall (Mine Shaft / Trial Tunnel)
    (0xD7A15431, 0x48E44EF6),
    # 05_portalpuzzle (Portal Terminal / Portal Site)
    (0x2BCD44A7, 0xBF7F572C),
    # 0c_sand_hall (Temple Access / Dark Agon Temple Access)
    (0x2A58AC44, 0x2103C8AE),
    # 0g_sand_hall (Central Station Access / Warrior's Walk)
    (0xFE69E0C3, 0x33FACC15),
    # 00_save_sand_a (Sand Cache / Save Station 1)
    (0xF4B1F727, 0x5A154E2E),
    # 0n_sand_hall (Portal Access A / Portal Access)
    (0x2312EE1D, 0x89D246FD),
    # 03_sand_temple (Agon Temple / Dark Agon Temple)
    (0x75FC9AAE, 0x7575048A),
    # 06_sand_alamofront (Central Mining Station / Battleground)
    (0xF5A6D972, 0xEA79522C),
    # 00_sand_generator_connect (Controller Access / Dark Controller Access)
    (0xBF5399C0, 0xA2F347D1),
    # 0h_sand_hall (Command Center Access / Double Path)
    (0x708387F9, 0x7FEF433B),
    # 00_sand_generator (Agon Energy Controller / Dark Agon Energy Controller)
    (0x02FC3717, 0xB7DD4006),
    # 07_sand_alamoportalobservation (Command Center / Doomed Entry)
    (0x31C25557, 0xA49F8A6D),
    # 10_sand_alamostorage (Main Reactor / Dark Oasis)
    (0xCCD9F39E, 0x99FB957F),
    # 0i_sand_hall (Biostorage Access / Feeding Pit Access)
    (0xDEEB1668, 0xE035C0A5),
    # 0m_sand_hall (Security Station B / Oasis Access)
    (0x0ADA5AEF, 0xF2CCC41E),
    # 0l_sand_hall (Sand Processing / Hall of Stairs)
    (0xA4B2CB7E, 0x6D164780),
    # 00_pickup_sand_d (Storage D / Ing Cache 3)
    (0x40FFA8F7, 0xBA23E5F5),
    # 08_sand_casualpirates (Biostorage Station / Feeding Pit)
    (0x80896CE9, 0x075A76EB),
    # 00_save_sand_c (Save Station C / Save Station 3)
    (0xB979562C, 0x0279F7EF),
    # 0j_sand_hall (Security Station A / Watering Hole)
    (0xF723A29A, 0x9B2B4246),
    # 00_pickup_sand_b (Storage B / Ing Cache 1)
    (0x96A64BEA, 0x52962FB6),
    # 0k_sand_hall (Ventilation Area B / Bitter Well)
    (0x594B330B, 0x04F1C1D8),
    # 09_sand_testtubepuzzle (Bioenergy Production / Phazon Site)
    (0x13470DA8, 0x200EF5E7),
    # 00_pickup_sand_c (Storage C / Ing Cache 2)
    (0x5DFA984F, 0x9318F076),
]

TORVUS_PAIRS = [
    # 01_swamp_entrance (Torvus Lagoon / Poisoned Bog)
    (0x7E0BE699, 0x14E2C3A6),
    # 0d_swamp_hall (Ruined Alcove / Putrid Alcove)
    (0xD37C2414, 0xCBC72D79),
    # 0c_swamp_hall (Portal Chamber / Portal Chamber)
    (0xF3EE585F, 0xAE1E1339),
    # 00_pickup_swamp_a (Save Station A / Cache A)
    (0xDB6E4075, 0x0CAAEEC6),
    # 03_swamp_forgottenbridge (Forgotten Bridge / Dark Forgotten Bridge)
    (0x09DECF21, 0x0253782D),
    # 02_swamp_greatbridge (Great Bridge / Venomous Pond)
    (0xE3D5A55E, 0x858EECD3),
    # 0i_swamp_hall (Plaza Access / Dark Arena Tunnel)
    (0xC1C28706, 0x390DFCB9),
    # 0e_swamp_hall (Abandoned Worksite / Brooding Ground)
    (0x54DAEF57, 0xDCEF49B9),
    # 0h_swamp_hall (Grove Access / Dark Falls)
    (0x46644C45, 0x2E259879),
    # 0f_swamp_hall (Temple Access / Dark Torvus Temple Access)
    (0x0740B4D3, 0xE597E4F9),
    # 00_map_swamp (Torvus Map Station / Save Station 1)
    (0x282B587F, 0x9A777442),
    # 06_swamp_boostballguardian (Torvus Plaza / Dark Torvus Arena)
    (0x75F158FF, 0xA49A572F),
    # 05_swamp_timber! (Torvus Grove / Polluted Mire)
    (0xE838FA18, 0x839DC4F6),
    # 04_swamp_temple (Torvus Temple / Dark Torvus Temple)
    (0xE640CE96, 0x3663B195),
    # 00_pickup_swamp_b (Meditation Vista / Gloom Vista)
    (0x5DFA32DB, 0x954888C7),
    # 00_elev_swamp_sand_e (Transport to Agon Wastes / Ammo Station)
    (0xCF659F4E, 0x8697F62A),
    # 0j_swamp_hall (Underground Transport / Cache B)
    (0x9258DC82, 0x007551F9),
    # 00_swamp_genconnect (Controller Access / Dark Controller Access)
    (0x2AF65B49, 0x11C4526B),
    # 07_swamp_shaft (Hydrodynamo Station / Undertemple Shaft)
    (0xD5B5B066, 0xB2D3E26C),
    # 00_swamp_generator (Torvus Energy Controller / Dark Torvus Energy Controller)
    (0x133BF5B8, 0x5ED7CD19),
    # 0l_swamphall (Gathering Access / Crypt Tunnel)
    (0x530DFF81, 0x4DC421AD),
    # ok_swamp_hall (Training Access / Sacrificial Chamber Tunnel)
    (0x77AF9FD1, 0x65E571CD),
    # 00_save_swamp_b (Save Station B / Save Station 2)
    (0xCB165BD8, 0x13254EC6),
    # 0q_swamp_hall (Hydrodynamo Shaft / Undertemple Access)
    (0x308351E5, 0x29B990F8),
    # 10_swamp_hiddenhalfpipe (Gathering Hall / Crypt)
    (0x3501473A, 0xC8A84B98),
    # 08_swamp_grappleguardian (Training Chamber / Sacrificial Chamber)
    (0x4BB5AE60, 0x629790F4),
    # 09_swamp_catacombs (Catacombs / Dungeon)
    (0xFB628DCB, 0xBBE4B3AE),
    # 11_swamp_bloggtank (Main Hydrochamber / Undertemple)
    (0xCEBAC0BD, 0x85A3801F),
    # 0n_swamp_hall (Transit Tunnel West / Undertransit One)
    (0xE150FB4D, 0x5CD4C2F9),
    # 0o_swamp_hall (Transit Tunnel East / Undertransit Two)
    (0x66F6300E, 0x4BFCA639),
]

SANCTUARY_PAIRS = [
    # 01_cliff_entrance (Sanctuary Entrance / Hive Entrance)
    (0x47265C0B, 0xF3FA4121),
    # 0b_cliff_hall (Power Junction / Entrance Defense Hall)
    (0x31C07D16, 0xA70EA82B),
    # 0c_cliff_hall (Reactor Access / Hive Reactor Access)
    (0xB666B655, 0xB026CCEB),
    # 02_cliff_reactorcore (Reactor Core / Hive Reactor)
    (0x4A6CF295, 0xF8DBC03D),
    # 00_save_cliff_a (Save Station A / Hive Save Station 1)
    (0x65B801CE, 0xBB57222F),
    # 0d_cliff_hall (Minigyro Chamber / Unseen Way)
    (0x96F4CA1E, 0xD5FFF2AB),
    # 0m_cliff_hall (Transit Station / Hive Portal Chamber)
    (0xF7424EC3, 0x7B94B06B),
    # 00_pickup_cliff_a (Sanctuary Map Station / Hive Cache 1)
    (0x52BF89F3, 0x5F43767D),
    # 03_cliff_chicane (Hall of Combat Mastery / Culling Chamber)
    (0x5571E89E, 0x690B786A),
    # 04_cliff_contraption (Main Research / Staging Area)
    (0x914F1381, 0x5BBF334F),
    # 0q_cliff_hall (Agon Transport Access / Hazing Cliff)
    (0x750BBFEF, 0x37814F2A),
    # 0e_cliff_hall (Central Area Transport East / Central Hive East Transport)
    (0x1152015D, 0xC2D7966B),
    # 0l_cliff_hall (Central Area Transport West / Central Hive West Transport)
    (0x70E48580, 0x6CBCD4AB),
    # 06_cliff_spiderballguardian (Dynamo Works / Hive Dynamo Works)
    (0xC0113CE8, 0xF24EF6B4),
    # 08_cliff_ringtowers (Watch Station / Aerial Training Site)
    (0xA2406387, 0x40F7447E),
    # 0f_cliff_hall (Dynamo Access / Hive Dynamo Access)
    (0x42C85AD9, 0xFBAF3B2B),
    # 00_pickup_cliff_c (Dynamo Storage / Hive Cache 3)
    (0x1F7728F8, 0x072FCFBC),
    # 0n_cliff_hall (Sentinel's Path / Temple Security Access)
    (0xA4D81547, 0x42EC1D2B),
    # 0o_cliff_hall (Grand Abyss / Judgment Drop)
    (0x237EDE04, 0x55C479EB),
    # 07cliff_gyro (Main Gyro Chamber / Hive Gyro Chamber)
    (0x73342A54, 0xA3656292),
    # 09_cliff_temple (Sanctuary Temple / Hive Temple)
    (0x6C363CD4, 0xA92F00B3),
    # 05_cliff_engineroom (Vault / Vault Attack Portal)
    (0x52254361, 0x1DF13149),
    # 0g_cliff_hall (Temple Access / Hive Temple Access)
    (0xC56E919A, 0xEC875FEB),
    # 0i_cliff_hall (Checkpoint Station / Hive Gyro Access)
    (0x844A690C, 0x2735236B),
    # 00_save_cliff_b (Save Station B / Hive Save Station 2)
    (0xE32C7360, 0x22B5442E),
    # 00_cliff_generator_connect (Controller Access / Hive Controller Access)
    (0xE89BDC92, 0x26AC7F1E),
    # 0j_cliff_hall_bottom (Aerie Transport Station / Hive Ammo Station)
    (0xBAF94A13, 0xF1DF78DC),
    # 00_cliff_generator (Sanctuary Energy Controller / Hive Energy Controller)
    (0x0D032A6A, 0x2DECC318),
    # 10_cliff_rooftop (Aerie / Hive Summit)
    (0x5D3A0001, 0x9D804955),
]

GREAT_TEMPLE_PAIRS = [
    # 07_temple_mothlordsanctuary (Temple Sanctuary / Sanctum)
    (0xA2CB7E32, 0xD7C3B839),
    # 0h_temple_hall (Controller Transport / Sanctum Access)
    (0x11E50BC6, 0xCBAD889B),
    # 08_temple_sungenerator (Main Energy Controller / Sky Temple Energy Controller)
    (0x02A01334, 0x7B4AFA6F),
]
