# Generated by asset_id_files.py

CONTROLLER_TRANSPORT_MREA = 0x11E50BC6
MAIN_ENERGY_CONTROLLER_MREA = 0x02A01334
SANCTUM_MREA = 0xD7C3B839
SANCTUM_ACCESS_MREA = 0xCBAD889B
SKY_TEMPLE_ENERGY_CONTROLLER_MREA = 0x7B4AFA6F
TEMPLE_SANCTUARY_MREA = 0xA2CB7E32
TEMPLE_TRANSPORT_A_MREA = 0x185B40F0
TEMPLE_TRANSPORT_B_MREA = 0x8F01B104
TEMPLE_TRANSPORT_C_MREA = 0x9860CBB0
TRANSPORT_A_ACCESS_MREA = 0xE79AAFAE
TRANSPORT_B_ACCESS_MREA = 0xFEB7BD27
TRANSPORT_C_ACCESS_MREA = 0x1A4DDCC0

NAME_TO_ID_MREA = {
    "Controller Transport": 0x11E50BC6,
    "Main Energy Controller": 0x02A01334,
    "Sanctum": 0xD7C3B839,
    "Sanctum Access": 0xCBAD889B,
    "Sky Temple Energy Controller": 0x7B4AFA6F,
    "Temple Sanctuary": 0xA2CB7E32,
    "Temple Transport A": 0x185B40F0,
    "Temple Transport B": 0x8F01B104,
    "Temple Transport C": 0x9860CBB0,
    "Transport A Access": 0xE79AAFAE,
    "Transport B Access": 0xFEB7BD27,
    "Transport C Access": 0x1A4DDCC0,
}
# Generated by asset_id_files.py

CONTROLLER_TRANSPORT_MAPA = 0x3830F0FB
MAIN_ENERGY_CONTROLLER_MAPA = 0x2B75E809
SANCTUM_MAPA = 0xFE164304
SANCTUM_ACCESS_MAPA = 0xE27873A6
SKY_TEMPLE_ENERGY_CONTROLLER_MAPA = 0x529F0152
TEMPLE_SANCTUARY_MAPA = 0x8B1E850F
TEMPLE_TRANSPORT_A_MAPA = 0x318EBBCD
TEMPLE_TRANSPORT_B_MAPA = 0xA6D44A39
TEMPLE_TRANSPORT_C_MAPA = 0xB1B5308D
TRANSPORT_A_ACCESS_MAPA = 0xCE4F5493
TRANSPORT_B_ACCESS_MAPA = 0xD762461A
TRANSPORT_C_ACCESS_MAPA = 0x339827FD

NAME_TO_ID_MAPA = {
    "Controller Transport": 0x3830F0FB,
    "Main Energy Controller": 0x2B75E809,
    "Sanctum": 0xFE164304,
    "Sanctum Access": 0xE27873A6,
    "Sky Temple Energy Controller": 0x529F0152,
    "Temple Sanctuary": 0x8B1E850F,
    "Temple Transport A": 0x318EBBCD,
    "Temple Transport B": 0xA6D44A39,
    "Temple Transport C": 0xB1B5308D,
    "Transport A Access": 0xCE4F5493,
    "Transport B Access": 0xD762461A,
    "Transport C Access": 0x339827FD,
}
# Generated by asset_id_files.py

CONTROLLER_TRANSPORT_INTERNAL_ID = 0xFF8C5AD6
MAIN_ENERGY_CONTROLLER_INTERNAL_ID = 0x7E6249F4
SANCTUM_INTERNAL_ID = 0x1E265BC2
SANCTUM_ACCESS_INTERNAL_ID = 0x05484014
SKY_TEMPLE_ENERGY_CONTROLLER_INTERNAL_ID = 0x8D1B96EB
TEMPLE_SANCTUARY_INTERNAL_ID = 0xDC8B67D3
TEMPLE_TRANSPORT_A_INTERNAL_ID = 0x6B65085B
TEMPLE_TRANSPORT_B_INTERNAL_ID = 0x49BFB670
TEMPLE_TRANSPORT_C_INTERNAL_ID = 0x6546B2B9
TRANSPORT_A_ACCESS_INTERNAL_ID = 0x628F4FC2
TRANSPORT_B_ACCESS_INTERNAL_ID = 0x89F0943F
TRANSPORT_C_ACCESS_INTERNAL_ID = 0xFD0E6733

NAME_TO_ID_INTERNAL_ID = {
    "Controller Transport": 0xFF8C5AD6,
    "Main Energy Controller": 0x7E6249F4,
    "Sanctum": 0x1E265BC2,
    "Sanctum Access": 0x05484014,
    "Sky Temple Energy Controller": 0x8D1B96EB,
    "Temple Sanctuary": 0xDC8B67D3,
    "Temple Transport A": 0x6B65085B,
    "Temple Transport B": 0x49BFB670,
    "Temple Transport C": 0x6546B2B9,
    "Transport A Access": 0x628F4FC2,
    "Transport B Access": 0x89F0943F,
    "Transport C Access": 0xFD0E6733,
}

DOCK_NAMES = {
    "Controller Transport": {
        "NorthBottom": 0,
        "NorthTop": 1,
    },
    "Main Energy Controller": {
        "SouthLight": 0,
        "VirtualNorth": 1,
        "North1": 2,
    },
    "Sanctum": {
        "SouthDark": 0,
    },
    "Sanctum Access": {
        "DarkTop": 0,
        "Darkbottom": 1,
    },
    "Sky Temple Energy Controller": {
        "SouthLight": 0,
        "VirtualNorth": 1,
    },
    "Temple Sanctuary": {
        "North": 0,
        "West": 1,
        "South": 2,
        "East": 3,
    },
    "Temple Transport A": {
        "South": 0,
    },
    "Temple Transport B": {
        "West": 0,
    },
    "Temple Transport C": {
        "East": 0,
    },
    "Transport A Access": {
        "North": 0,
        "South": 1,
    },
    "Transport B Access": {
        "West": 0,
        "East": 1,
    },
    "Transport C Access": {
        "East": 0,
        "West": 1,
    },
}
