# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_MREA = 0x40F7447E
AERIE_MREA = 0x5D3A0001
AERIE_ACCESS_MREA = 0xDF073157
AERIE_TRANSPORT_STATION_MREA = 0xBAF94A13
AGON_TRANSPORT_ACCESS_MREA = 0x750BBFEF
CENTRAL_AREA_TRANSPORT_EAST_MREA = 0x1152015D
CENTRAL_AREA_TRANSPORT_WEST_MREA = 0x70E48580
CENTRAL_HIVE_EAST_TRANSPORT_MREA = 0xC2D7966B
CENTRAL_HIVE_WEST_TRANSPORT_MREA = 0x6CBCD4AB
CHECKPOINT_STATION_MREA = 0x844A690C
CONTROLLER_ACCESS_MREA = 0xE89BDC92
CULLING_CHAMBER_MREA = 0x690B786A
DYNAMO_ACCESS_MREA = 0x42C85AD9
DYNAMO_STORAGE_MREA = 0x1F7728F8
DYNAMO_WORKS_MREA = 0xC0113CE8
ENTRANCE_DEFENSE_HALL_MREA = 0xA70EA82B
GRAND_ABYSS_MREA = 0x237EDE04
HALL_OF_COMBAT_MASTERY_MREA = 0x5571E89E
HAZING_CLIFF_MREA = 0x37814F2A
HIVE_AMMO_STATION_MREA = 0xF1DF78DC
HIVE_CACHE_1_MREA = 0x5F43767D
HIVE_CACHE_3_MREA = 0x072FCFBC
HIVE_CONTROLLER_ACCESS_MREA = 0x26AC7F1E
HIVE_DYNAMO_ACCESS_MREA = 0xFBAF3B2B
HIVE_DYNAMO_WORKS_MREA = 0xF24EF6B4
HIVE_ENERGY_CONTROLLER_MREA = 0x2DECC318
HIVE_ENTRANCE_MREA = 0xF3FA4121
HIVE_GYRO_ACCESS_MREA = 0x2735236B
HIVE_GYRO_CHAMBER_MREA = 0xA3656292
HIVE_PORTAL_CHAMBER_MREA = 0x7B94B06B
HIVE_REACTOR_MREA = 0xF8DBC03D
HIVE_REACTOR_ACCESS_MREA = 0xB026CCEB
HIVE_SAVE_STATION_1_MREA = 0xBB57222F
HIVE_SAVE_STATION_2_MREA = 0x22B5442E
HIVE_SUMMIT_MREA = 0x9D804955
HIVE_TEMPLE_MREA = 0xA92F00B3
HIVE_TEMPLE_ACCESS_MREA = 0xEC875FEB
JUDGMENT_DROP_MREA = 0x55C479EB
MAIN_ENERGY_CONTROLLER_MREA = 0x57134DC2
MAIN_GYRO_CHAMBER_MREA = 0x73342A54
MAIN_RESEARCH_MREA = 0x914F1381
MINIGYRO_CHAMBER_MREA = 0x96F4CA1E
POWER_JUNCTION_MREA = 0x31C07D16
REACTOR_ACCESS_MREA = 0xB666B655
REACTOR_CORE_MREA = 0x4A6CF295
SANCTUARY_ENERGY_CONTROLLER_MREA = 0x0D032A6A
SANCTUARY_ENTRANCE_MREA = 0x47265C0B
SANCTUARY_MAP_STATION_MREA = 0x52BF89F3
SANCTUARY_TEMPLE_MREA = 0x6C363CD4
SAVE_STATION_A_MREA = 0x65B801CE
SAVE_STATION_B_MREA = 0xE32C7360
SENTINELS_PATH_MREA = 0xA4D81547
STAGING_AREA_MREA = 0x5BBF334F
TEMPLE_ACCESS_MREA = 0xC56E919A
TEMPLE_SECURITY_ACCESS_MREA = 0x42EC1D2B
TEMPLE_TRANSPORT_ACCESS_MREA = 0x625A2692
TORVUS_TRANSPORT_ACCESS_MREA = 0xF2AD74AC
TRANSIT_STATION_MREA = 0xF7424EC3
TRANSPORT_TO_AGON_WASTES_MREA = 0x35A94603
TRANSPORT_TO_TEMPLE_GROUNDS_MREA = 0xD24B673D
TRANSPORT_TO_TORVUS_BOG_MREA = 0xBB77569E
UNSEEN_WAY_MREA = 0xD5FFF2AB
VAULT_MREA = 0x52254361
VAULT_ATTACK_PORTAL_MREA = 0x1DF13149
WATCH_STATION_MREA = 0xA2406387
WATCH_STATION_ACCESS_MREA = 0x5076F9CB
WORKERS_PATH_MREA = 0x03ECA24F

NAME_TO_ID_MREA = {
    "Aerial Training Site": 0x40F7447E,
    "Aerie": 0x5D3A0001,
    "Aerie Access": 0xDF073157,
    "Aerie Transport Station": 0xBAF94A13,
    "Agon Transport Access": 0x750BBFEF,
    "Central Area Transport East": 0x1152015D,
    "Central Area Transport West": 0x70E48580,
    "Central Hive East Transport": 0xC2D7966B,
    "Central Hive West Transport": 0x6CBCD4AB,
    "Checkpoint Station": 0x844A690C,
    "Controller Access": 0xE89BDC92,
    "Culling Chamber": 0x690B786A,
    "Dynamo Access": 0x42C85AD9,
    "Dynamo Storage": 0x1F7728F8,
    "Dynamo Works": 0xC0113CE8,
    "Entrance Defense Hall": 0xA70EA82B,
    "Grand Abyss": 0x237EDE04,
    "Hall of Combat Mastery": 0x5571E89E,
    "Hazing Cliff": 0x37814F2A,
    "Hive Ammo Station": 0xF1DF78DC,
    "Hive Cache 1": 0x5F43767D,
    "Hive Cache 3": 0x072FCFBC,
    "Hive Controller Access": 0x26AC7F1E,
    "Hive Dynamo Access": 0xFBAF3B2B,
    "Hive Dynamo Works": 0xF24EF6B4,
    "Hive Energy Controller": 0x2DECC318,
    "Hive Entrance": 0xF3FA4121,
    "Hive Gyro Access": 0x2735236B,
    "Hive Gyro Chamber": 0xA3656292,
    "Hive Portal Chamber": 0x7B94B06B,
    "Hive Reactor": 0xF8DBC03D,
    "Hive Reactor Access": 0xB026CCEB,
    "Hive Save Station 1": 0xBB57222F,
    "Hive Save Station 2": 0x22B5442E,
    "Hive Summit": 0x9D804955,
    "Hive Temple": 0xA92F00B3,
    "Hive Temple Access": 0xEC875FEB,
    "Judgment Drop": 0x55C479EB,
    "Main Energy Controller": 0x57134DC2,
    "Main Gyro Chamber": 0x73342A54,
    "Main Research": 0x914F1381,
    "Minigyro Chamber": 0x96F4CA1E,
    "Power Junction": 0x31C07D16,
    "Reactor Access": 0xB666B655,
    "Reactor Core": 0x4A6CF295,
    "Sanctuary Energy Controller": 0x0D032A6A,
    "Sanctuary Entrance": 0x47265C0B,
    "Sanctuary Map Station": 0x52BF89F3,
    "Sanctuary Temple": 0x6C363CD4,
    "Save Station A": 0x65B801CE,
    "Save Station B": 0xE32C7360,
    "Sentinel's Path": 0xA4D81547,
    "Staging Area": 0x5BBF334F,
    "Temple Access": 0xC56E919A,
    "Temple Security Access": 0x42EC1D2B,
    "Temple Transport Access": 0x625A2692,
    "Torvus Transport Access": 0xF2AD74AC,
    "Transit Station": 0xF7424EC3,
    "Transport to Agon Wastes": 0x35A94603,
    "Transport to Temple Grounds": 0xD24B673D,
    "Transport to Torvus Bog": 0xBB77569E,
    "Unseen Way": 0xD5FFF2AB,
    "Vault": 0x52254361,
    "Vault Attack Portal": 0x1DF13149,
    "Watch Station": 0xA2406387,
    "Watch Station Access": 0x5076F9CB,
    "Workers Path": 0x03ECA24F,
}
# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_MAPA = 0x6922BF43
AERIE_MAPA = 0x74EFFB3C
AERIE_ACCESS_MAPA = 0xF6D2CA6A
AERIE_TRANSPORT_STATION_MAPA = 0x932CB12E
AGON_TRANSPORT_ACCESS_MAPA = 0x5CDE44D2
CENTRAL_AREA_TRANSPORT_EAST_MAPA = 0x3887FA60
CENTRAL_AREA_TRANSPORT_WEST_MAPA = 0x59317EBD
CENTRAL_HIVE_EAST_TRANSPORT_MAPA = 0xEB026D56
CENTRAL_HIVE_WEST_TRANSPORT_MAPA = 0x45692F96
CHECKPOINT_STATION_MAPA = 0xAD9F9231
CONTROLLER_ACCESS_MAPA = 0xC14E27AF
CULLING_CHAMBER_MAPA = 0x40DE8357
DYNAMO_ACCESS_MAPA = 0x6B1DA1E4
DYNAMO_STORAGE_MAPA = 0x36A2D3C5
DYNAMO_WORKS_MAPA = 0xE9C4C7D5
ENTRANCE_DEFENSE_HALL_MAPA = 0x8EDB5316
GRAND_ABYSS_MAPA = 0x0AAB2539
HALL_OF_COMBAT_MASTERY_MAPA = 0x7CA413A3
HAZING_CLIFF_MAPA = 0x1E54B417
HIVE_AMMO_STATION_MAPA = 0xD80A83E1
HIVE_CACHE_1_MAPA = 0x76968D40
HIVE_CACHE_3_MAPA = 0x2EFA3481
HIVE_CONTROLLER_ACCESS_MAPA = 0x0F798423
HIVE_DYNAMO_ACCESS_MAPA = 0xD27AC016
HIVE_DYNAMO_WORKS_MAPA = 0xDB9B0D89
HIVE_ENERGY_CONTROLLER_MAPA = 0x04393825
HIVE_ENTRANCE_MAPA = 0xDA2FBA1C
HIVE_GYRO_ACCESS_MAPA = 0x0EE0D856
HIVE_GYRO_CHAMBER_MAPA = 0x8AB099AF
HIVE_PORTAL_CHAMBER_MAPA = 0x52414B56
HIVE_REACTOR_MAPA = 0xD10E3B00
HIVE_REACTOR_ACCESS_MAPA = 0x99F337D6
HIVE_SAVE_STATION_1_MAPA = 0x9282D912
HIVE_SAVE_STATION_2_MAPA = 0x0B60BF13
HIVE_SUMMIT_MAPA = 0xB455B268
HIVE_TEMPLE_MAPA = 0x80FAFB8E
HIVE_TEMPLE_ACCESS_MAPA = 0xC552A4D6
JUDGMENT_DROP_MAPA = 0x7C1182D6
MAIN_ENERGY_CONTROLLER_MAPA = 0x7EC6B6FF
MAIN_GYRO_CHAMBER_MAPA = 0x5AE1D169
MAIN_RESEARCH_MAPA = 0xB89AE8BC
MINIGYRO_CHAMBER_MAPA = 0xBF213123
POWER_JUNCTION_MAPA = 0x1815862B
REACTOR_ACCESS_MAPA = 0x9FB34D68
REACTOR_CORE_MAPA = 0x63B909A8
SANCTUARY_ENERGY_CONTROLLER_MAPA = 0x24D6D157
SANCTUARY_ENTRANCE_MAPA = 0x6EF3A736
SANCTUARY_MAP_STATION_MAPA = 0x7B6A72CE
SANCTUARY_TEMPLE_MAPA = 0x45E3C7E9
SAVE_STATION_A_MAPA = 0x4C6DFAF3
SAVE_STATION_B_MAPA = 0xCAF9885D
SENTINELS_PATH_MAPA = 0x8D0DEE7A
STAGING_AREA_MAPA = 0x726AC872
TEMPLE_ACCESS_MAPA = 0xECBB6AA7
TEMPLE_SECURITY_ACCESS_MAPA = 0x6B39E616
TEMPLE_TRANSPORT_ACCESS_MAPA = 0x4B8FDDAF
TORVUS_TRANSPORT_ACCESS_MAPA = 0xDB788F91
TRANSIT_STATION_MAPA = 0xDE97B5FE
TRANSPORT_TO_AGON_WASTES_MAPA = 0x1C7CBD3E
TRANSPORT_TO_TEMPLE_GROUNDS_MAPA = 0xFB9E9C00
TRANSPORT_TO_TORVUS_BOG_MAPA = 0x92A2ADA3
UNSEEN_WAY_MAPA = 0xFC2A0996
VAULT_MAPA = 0x7BF0B85C
VAULT_ATTACK_PORTAL_MAPA = 0x3424CA74
WATCH_STATION_MAPA = 0x8B9598BA
WATCH_STATION_ACCESS_MAPA = 0x79A302F6
WORKERS_PATH_MAPA = 0x2A395972

NAME_TO_ID_MAPA = {
    "Aerial Training Site": 0x6922BF43,
    "Aerie": 0x74EFFB3C,
    "Aerie Access": 0xF6D2CA6A,
    "Aerie Transport Station": 0x932CB12E,
    "Agon Transport Access": 0x5CDE44D2,
    "Central Area Transport East": 0x3887FA60,
    "Central Area Transport West": 0x59317EBD,
    "Central Hive East Transport": 0xEB026D56,
    "Central Hive West Transport": 0x45692F96,
    "Checkpoint Station": 0xAD9F9231,
    "Controller Access": 0xC14E27AF,
    "Culling Chamber": 0x40DE8357,
    "Dynamo Access": 0x6B1DA1E4,
    "Dynamo Storage": 0x36A2D3C5,
    "Dynamo Works": 0xE9C4C7D5,
    "Entrance Defense Hall": 0x8EDB5316,
    "Grand Abyss": 0x0AAB2539,
    "Hall of Combat Mastery": 0x7CA413A3,
    "Hazing Cliff": 0x1E54B417,
    "Hive Ammo Station": 0xD80A83E1,
    "Hive Cache 1": 0x76968D40,
    "Hive Cache 3": 0x2EFA3481,
    "Hive Controller Access": 0x0F798423,
    "Hive Dynamo Access": 0xD27AC016,
    "Hive Dynamo Works": 0xDB9B0D89,
    "Hive Energy Controller": 0x04393825,
    "Hive Entrance": 0xDA2FBA1C,
    "Hive Gyro Access": 0x0EE0D856,
    "Hive Gyro Chamber": 0x8AB099AF,
    "Hive Portal Chamber": 0x52414B56,
    "Hive Reactor": 0xD10E3B00,
    "Hive Reactor Access": 0x99F337D6,
    "Hive Save Station 1": 0x9282D912,
    "Hive Save Station 2": 0x0B60BF13,
    "Hive Summit": 0xB455B268,
    "Hive Temple": 0x80FAFB8E,
    "Hive Temple Access": 0xC552A4D6,
    "Judgment Drop": 0x7C1182D6,
    "Main Energy Controller": 0x7EC6B6FF,
    "Main Gyro Chamber": 0x5AE1D169,
    "Main Research": 0xB89AE8BC,
    "Minigyro Chamber": 0xBF213123,
    "Power Junction": 0x1815862B,
    "Reactor Access": 0x9FB34D68,
    "Reactor Core": 0x63B909A8,
    "Sanctuary Energy Controller": 0x24D6D157,
    "Sanctuary Entrance": 0x6EF3A736,
    "Sanctuary Map Station": 0x7B6A72CE,
    "Sanctuary Temple": 0x45E3C7E9,
    "Save Station A": 0x4C6DFAF3,
    "Save Station B": 0xCAF9885D,
    "Sentinel's Path": 0x8D0DEE7A,
    "Staging Area": 0x726AC872,
    "Temple Access": 0xECBB6AA7,
    "Temple Security Access": 0x6B39E616,
    "Temple Transport Access": 0x4B8FDDAF,
    "Torvus Transport Access": 0xDB788F91,
    "Transit Station": 0xDE97B5FE,
    "Transport to Agon Wastes": 0x1C7CBD3E,
    "Transport to Temple Grounds": 0xFB9E9C00,
    "Transport to Torvus Bog": 0x92A2ADA3,
    "Unseen Way": 0xFC2A0996,
    "Vault": 0x7BF0B85C,
    "Vault Attack Portal": 0x3424CA74,
    "Watch Station": 0x8B9598BA,
    "Watch Station Access": 0x79A302F6,
    "Workers Path": 0x2A395972,
}
# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_INTERNAL_ID = 0x66B72B0E
AERIE_INTERNAL_ID = 0xE380B5A7
AERIE_ACCESS_INTERNAL_ID = 0xADBAE729
AERIE_TRANSPORT_STATION_INTERNAL_ID = 0xDCCFF2C6
AGON_TRANSPORT_ACCESS_INTERNAL_ID = 0x9B7F9FE8
CENTRAL_AREA_TRANSPORT_EAST_INTERNAL_ID = 0x28065DD3
CENTRAL_AREA_TRANSPORT_WEST_INTERNAL_ID = 0xF16BAE04
CENTRAL_HIVE_EAST_TRANSPORT_INTERNAL_ID = 0x3D646F91
CENTRAL_HIVE_WEST_TRANSPORT_INTERNAL_ID = 0x527BF6C1
CHECKPOINT_STATION_INTERNAL_ID = 0x46D11C3A
CONTROLLER_ACCESS_INTERNAL_ID = 0x188B5EAB
CULLING_CHAMBER_INTERNAL_ID = 0x3A73B33D
DYNAMO_ACCESS_INTERNAL_ID = 0x456FCC39
DYNAMO_STORAGE_INTERNAL_ID = 0x6390C1F6
DYNAMO_WORKS_INTERNAL_ID = 0xFB3385B5
ENTRANCE_DEFENSE_HALL_INTERNAL_ID = 0xAEBE1A9E
GRAND_ABYSS_INTERNAL_ID = 0x9C023FEE
HALL_OF_COMBAT_MASTERY_INTERNAL_ID = 0x66D7D514
HAZING_CLIFF_INTERNAL_ID = 0x401F39E7
HIVE_AMMO_STATION_INTERNAL_ID = 0x5125F5DA
HIVE_CACHE_1_INTERNAL_ID = 0x5A61C7C3
HIVE_CACHE_3_INTERNAL_ID = 0x33713618
HIVE_CONTROLLER_ACCESS_INTERNAL_ID = 0x2B60A33B
HIVE_DYNAMO_ACCESS_INTERNAL_ID = 0x6CC65DFA
HIVE_DYNAMO_WORKS_INTERNAL_ID = 0x6F096BED
HIVE_ENERGY_CONTROLLER_INTERNAL_ID = 0xA9FB8A2B
HIVE_ENTRANCE_INTERNAL_ID = 0x59145ED7
HIVE_GYRO_ACCESS_INTERNAL_ID = 0xA09DA07C
HIVE_GYRO_CHAMBER_INTERNAL_ID = 0x125001F3
HIVE_PORTAL_CHAMBER_INTERNAL_ID = 0x62E5E718
HIVE_REACTOR_INTERNAL_ID = 0x504DE08E
HIVE_REACTOR_ACCESS_INTERNAL_ID = 0x9E200B47
HIVE_SAVE_STATION_1_INTERNAL_ID = 0x8F510E80
HIVE_SAVE_STATION_2_INTERNAL_ID = 0x774E8CF0
HIVE_SUMMIT_INTERNAL_ID = 0x36DE43EA
HIVE_TEMPLE_INTERNAL_ID = 0x57FF5720
HIVE_TEMPLE_ACCESS_INTERNAL_ID = 0x5C584C23
JUDGMENT_DROP_INTERNAL_ID = 0x03D9C4AA
MAIN_ENERGY_CONTROLLER_INTERNAL_ID = 0xD4B94644
MAIN_GYRO_CHAMBER_INTERNAL_ID = 0xED4F0ADD
MAIN_RESEARCH_INTERNAL_ID = 0x57E7BDCA
MINIGYRO_CHAMBER_INTERNAL_ID = 0xBA0E2F4A
POWER_JUNCTION_INTERNAL_ID = 0x60DD0C9E
REACTOR_ACCESS_INTERNAL_ID = 0xF2D57E07
REACTOR_CORE_INTERNAL_ID = 0xB54ABB81
SANCTUARY_ENERGY_CONTROLLER_INTERNAL_ID = 0x3A186834
SANCTUARY_ENTRANCE_INTERNAL_ID = 0xFF6D683B
SANCTUARY_MAP_STATION_INTERNAL_ID = 0xF4C6417F
SANCTUARY_TEMPLE_INTERNAL_ID = 0x64177921
SAVE_STATION_A_INTERNAL_ID = 0xA4028DAD
SAVE_STATION_B_INTERNAL_ID = 0x98BC759E
SENTINELS_PATH_INTERNAL_ID = 0x0E0A4D77
STAGING_AREA_INTERNAL_ID = 0x0073DF3D
TEMPLE_ACCESS_INTERNAL_ID = 0xD767BEA0
TEMPLE_SECURITY_ACCESS_INTERNAL_ID = 0x3347D573
TEMPLE_TRANSPORT_ACCESS_INTERNAL_ID = 0x0DB49D74
TORVUS_TRANSPORT_ACCESS_INTERNAL_ID = 0x0977ED71
TRANSIT_STATION_INTERNAL_ID = 0x6363DC9D
TRANSPORT_TO_AGON_WASTES_INTERNAL_ID = 0x0172721D
TRANSPORT_TO_TEMPLE_GROUNDS_INTERNAL_ID = 0x74EC5EB4
TRANSPORT_TO_TORVUS_BOG_INTERNAL_ID = 0xE7CD5281
UNSEEN_WAY_INTERNAL_ID = 0x0DFA7E48
VAULT_INTERNAL_ID = 0x95FFACC2
VAULT_ATTACK_PORTAL_INTERNAL_ID = 0x402BFBA9
WATCH_STATION_INTERNAL_ID = 0xCA9B1A72
WATCH_STATION_ACCESS_INTERNAL_ID = 0xB9B0FF49
WORKERS_PATH_INTERNAL_ID = 0xD4D96EA3

NAME_TO_ID_INTERNAL_ID = {
    "Aerial Training Site": 0x66B72B0E,
    "Aerie": 0xE380B5A7,
    "Aerie Access": 0xADBAE729,
    "Aerie Transport Station": 0xDCCFF2C6,
    "Agon Transport Access": 0x9B7F9FE8,
    "Central Area Transport East": 0x28065DD3,
    "Central Area Transport West": 0xF16BAE04,
    "Central Hive East Transport": 0x3D646F91,
    "Central Hive West Transport": 0x527BF6C1,
    "Checkpoint Station": 0x46D11C3A,
    "Controller Access": 0x188B5EAB,
    "Culling Chamber": 0x3A73B33D,
    "Dynamo Access": 0x456FCC39,
    "Dynamo Storage": 0x6390C1F6,
    "Dynamo Works": 0xFB3385B5,
    "Entrance Defense Hall": 0xAEBE1A9E,
    "Grand Abyss": 0x9C023FEE,
    "Hall of Combat Mastery": 0x66D7D514,
    "Hazing Cliff": 0x401F39E7,
    "Hive Ammo Station": 0x5125F5DA,
    "Hive Cache 1": 0x5A61C7C3,
    "Hive Cache 3": 0x33713618,
    "Hive Controller Access": 0x2B60A33B,
    "Hive Dynamo Access": 0x6CC65DFA,
    "Hive Dynamo Works": 0x6F096BED,
    "Hive Energy Controller": 0xA9FB8A2B,
    "Hive Entrance": 0x59145ED7,
    "Hive Gyro Access": 0xA09DA07C,
    "Hive Gyro Chamber": 0x125001F3,
    "Hive Portal Chamber": 0x62E5E718,
    "Hive Reactor": 0x504DE08E,
    "Hive Reactor Access": 0x9E200B47,
    "Hive Save Station 1": 0x8F510E80,
    "Hive Save Station 2": 0x774E8CF0,
    "Hive Summit": 0x36DE43EA,
    "Hive Temple": 0x57FF5720,
    "Hive Temple Access": 0x5C584C23,
    "Judgment Drop": 0x03D9C4AA,
    "Main Energy Controller": 0xD4B94644,
    "Main Gyro Chamber": 0xED4F0ADD,
    "Main Research": 0x57E7BDCA,
    "Minigyro Chamber": 0xBA0E2F4A,
    "Power Junction": 0x60DD0C9E,
    "Reactor Access": 0xF2D57E07,
    "Reactor Core": 0xB54ABB81,
    "Sanctuary Energy Controller": 0x3A186834,
    "Sanctuary Entrance": 0xFF6D683B,
    "Sanctuary Map Station": 0xF4C6417F,
    "Sanctuary Temple": 0x64177921,
    "Save Station A": 0xA4028DAD,
    "Save Station B": 0x98BC759E,
    "Sentinel's Path": 0x0E0A4D77,
    "Staging Area": 0x0073DF3D,
    "Temple Access": 0xD767BEA0,
    "Temple Security Access": 0x3347D573,
    "Temple Transport Access": 0x0DB49D74,
    "Torvus Transport Access": 0x0977ED71,
    "Transit Station": 0x6363DC9D,
    "Transport to Agon Wastes": 0x0172721D,
    "Transport to Temple Grounds": 0x74EC5EB4,
    "Transport to Torvus Bog": 0xE7CD5281,
    "Unseen Way": 0x0DFA7E48,
    "Vault": 0x95FFACC2,
    "Vault Attack Portal": 0x402BFBA9,
    "Watch Station": 0xCA9B1A72,
    "Watch Station Access": 0xB9B0FF49,
    "Workers Path": 0xD4D96EA3,
}

DOCK_NAMES = {
    "Aerial Training Site": {
        "South": 0,
        "West_0L": 1,
        "East": 2,
        "West_0O": 3,
        "VirtualNorth1": 4,
    },
    "Aerie": {
        "Docks_Floor": 0,
        "VirtualArenaDock": 1,
        "VirtualUnderStatueDock": 2,
    },
    "Aerie Access": {
        "Floor": 0,
        "Ceiling": 1,
    },
    "Aerie Transport Station": {
        "South": 0,
        "Ceiling": 1,
    },
    "Agon Transport Access": {
        "East": 0,
        "West": 1,
    },
    "Central Area Transport East": {
        "group1_West_04 (Top)": 0,
        "group1_West_07 (Bottom)": 1,
    },
    "Central Area Transport West": {
        "East_Top": 0,
        "East_Bottom": 1,
    },
    "Central Hive East Transport": {
        "group1_West_04 (Top)": 0,
        "group1_West_07 (Bottom)": 1,
    },
    "Central Hive West Transport": {
        "East_Top": 0,
        "East_Bottom": 1,
    },
    "Checkpoint Station": {
        "North": 0,
        "South": 1,
    },
    "Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Culling Chamber": {
        "EastHall": 0,
        "EastElevator": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Dynamo Access": {
        "West": 0,
        "East": 1,
    },
    "Dynamo Storage": {
        "group1_West": 0,
        "VirtualWest": 1,
    },
    "Dynamo Works": {
        "East 0E": 0,
        "West1 0F": 1,
        "South2 0H": 2,
        "East2 00_Pickup C": 3,
        "VirtualNorth": 4,
    },
    "Entrance Defense Hall": {
        "North2": 0,
        "South": 1,
    },
    "Grand Abyss": {
        "East": 0,
        "VirtualNorth": 1,
        "Ceiling": 2,
    },
    "Hall of Combat Mastery": {
        "EastHall": 0,
        "EastElevator": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Hazing Cliff": {
        "East": 0,
        "West": 1,
    },
    "Hive Ammo Station": {
        "South": 0,
        "Ceiling": 1,
    },
    "Hive Cache 1": {
        "South": 0,
    },
    "Hive Cache 3": {
        "group1_West": 0,
        "VirtualWest": 1,
    },
    "Hive Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Hive Dynamo Access": {
        "West": 0,
        "East": 1,
    },
    "Hive Dynamo Works": {
        "East": 0,
        "West1": 1,
        "South2 (Disabled)": 2,
        "East2": 3,
        "VirtualNorth": 4,
    },
    "Hive Energy Controller": {
        "North": 0,
    },
    "Hive Entrance": {
        "North": 0,
        "South": 1,
    },
    "Hive Gyro Access": {
        "North": 0,
        "South": 1,
    },
    "Hive Gyro Chamber": {
        "South": 0,
        "North1": 1,
        "West_Save": 2,
        "East1": 3,
        "West21": 4,
    },
    "Hive Portal Chamber": {
        "West": 0,
        "VirtualDock_South": 1,
        "VirtualDock_North_Right": 2,
        "VirtualDock_North_Left": 3,
        "VirtualDock_North_Middle": 4,
    },
    "Hive Reactor": {
        "North": 0,
        "East": 1,
        "South": 2,
        "North2": 3,
    },
    "Hive Reactor Access": {
        "North": 0,
        "South": 1,
    },
    "Hive Save Station 1": {
        "South": 0,
    },
    "Hive Save Station 2": {
        "East": 0,
    },
    "Hive Summit": {
        "Docks_Floor": 0,
        "VirtualArenaDock": 1,
        "VirtualUnderStatueDock": 2,
    },
    "Hive Temple": {
        "South": 0,
        "West": 1,
        "East": 2,
        "North": 3,
    },
    "Hive Temple Access": {
        "South": 0,
        "North": 1,
    },
    "Judgment Drop": {
        "East": 0,
        "VirtualNorth": 1,
    },
    "Main Energy Controller": {
        "SouthLight1": 0,
        "VirtualNorth": 1,
        "North1": 2,
    },
    "Main Gyro Chamber": {
        "South": 0,
        "North1": 1,
        "West_Save": 2,
        "East1": 3,
        "West21": 4,
    },
    "Main Research": {
        "West to 0l_cliff_hall": 0,
        "West1 to 0p_cliff_hall": 1,
        "East2 to 0m_cliff_hall": 2,
        "VirtualNorth": 3,
        "VirtualNorth1": 4,
        "North": 5,
    },
    "Minigyro Chamber": {
        "West": 0,
        "East": 1,
    },
    "Power Junction": {
        "North2": 0,
        "South": 1,
    },
    "Reactor Access": {
        "North": 0,
        "South": 1,
    },
    "Reactor Core": {
        "North": 0,
        "East": 1,
        "West": 2,
        "South": 3,
        "North2": 4,
    },
    "Sanctuary Energy Controller": {
        "North": 0,
        "North1 (to 08)": 1,
    },
    "Sanctuary Entrance": {
        "North": 0,
        "South": 1,
    },
    "Sanctuary Map Station": {
        "South": 0,
    },
    "Sanctuary Temple": {
        "South": 0,
        "West": 1,
        "East": 2,
        "North": 3,
    },
    "Save Station A": {
        "South": 0,
    },
    "Save Station B": {
        "East": 0,
    },
    "Sentinel's Path": {
        "East": 0,
        "North": 1,
    },
    "Staging Area": {
        "West": 0,
        "West1": 1,
        "East2": 2,
        "VirtualNorth": 3,
        "VirtualNorth1": 4,
        "North": 5,
    },
    "Temple Access": {
        "South": 0,
        "North": 1,
    },
    "Temple Security Access": {
        "East": 0,
        "North": 1,
    },
    "Temple Transport Access": {
        "South1": 0,
        "North1": 1,
    },
    "Torvus Transport Access": {
        "East": 0,
        "West": 1,
    },
    "Transit Station": {
        "West": 0,
        "East": 1,
        "VirtualDock_South": 2,
        "VirtualDock_North_Right": 3,
        "VirtualDock_North_Left": 4,
        "VirtualDock_North_Middle": 5,
    },
    "Transport to Agon Wastes": {
        "West": 0,
    },
    "Transport to Temple Grounds": {
        "North": 0,
    },
    "Transport to Torvus Bog": {
        "East": 0,
    },
    "Unseen Way": {
        "West": 0,
        "East": 1,
    },
    "Vault": {
        "East": 0,
        "VirtualWest": 1,
        "VirtualEast": 2,
    },
    "Vault Attack Portal": {
        "East": 0,
        "VirtualWest": 1,
        "VirtualEast": 2,
    },
    "Watch Station": {
        "South": 0,
        "WestDown": 1,
        "East": 2,
        "WestUp": 3,
        "VirtualNorth1": 4,
    },
    "Watch Station Access": {
        "East": 0,
        "West": 1,
    },
    "Workers Path": {
        "West": 0,
        "North": 1,
    },
}
