from retro_data_structures.base_resource import AssetId

SUIT_ASSETS: dict[str, dict[AssetId, str]] = {
    "varia": {
        0x788432DA: "samus_varia_visor.TXTR",
        0xC2DE6C2A: "samus_varia_visor_emissive.TXTR",
        0x86FF8630: "samus_varia_visor_polish.TXTR",
        0x12B6539F: "samus_varia_banding.TXTR",
        0x42DFBEBF: "samus_varia_banding_2.TXTR",
        0x604D4DC5: "samus_varia_flex.TXTR",
        0xE3001044: "samus_varia_flex_polish.TXTR",
        0xE8AF7174: "samus_varia_armor.TXTR",
        0xFFD9D212: "samus_varia_armor_polish.TXTR",
        0x8FF8E517: "samus_varia_trim.TXTR",
        0x2883811B: "samus_varia_trim_polish.TXTR",
        0x355E4212: "samus_varia_metallic.TXTR",
        0x0EF3BA76: "samus_varia_morph_shell.TXTR",
        0x0CC73555: "samus_varia_morph_emissive.TXTR",
        0x3C214DF7: "samus_varia_morph_banding.TXTR",
        0xAAEC3745: "samus_varia_morph_metallic.TXTR",
        0x1E5621F5: "samus_varia_low_res_armor.TXTR",
        0x97FEE0A8: "samus_varia_low_res_armor_polish.TXTR",
        0x23B19B14: "samus_varia_low_res_emissive.TXTR",
        0xDD1473FC: "samus_varia_low_res_metallic.TXTR",
        0x2777D332: "samus_varia_morph_2_shell.TXTR",
        0xEB669581: "samus_varia_morph_2_shell_polish.TXTR",
        0xA29AEF93: "samus_varia_morph_3_shell.TXTR",
        0x9643B175: "samus_varia_morph_3_shell_polish.TXTR",
        0x2F566CEC: "samus_morph_2_3_metallic.TXTR",
        0x9BD4E4B3: "samus_varia_armor_polish_2.TXTR",
        0xB29C1225: "samus_varia_left_arm_metallic.TXTR",
    },
    "dark": {
        0x022045C3: "samus_dark_visor.TXTR",
        0xA3BB66A5: "samus_dark_visor_emissive.TXTR",
        0x27805BC6: "samus_dark_visor_scanlines.TXTR",
        0xB29C1225: "samus_dark_visor_metallic.TXTR",
        0x9FCF0D60: "samus_dark_spot_accent.TXTR",
        0xB95FE642: "samus_dark_armor.TXTR",
        0x3B843F46: "samus_dark_armor_metallic.TXTR",
        0xA283E265: "samus_dark_backpack.TXTR",
        0x9255BD83: "samus_dark_morph.TXTR",
        0x33CE9EE5: "samus_dark_morph_emissive.TXTR",
        0x52E13615: "samus_dark_morph_polish.TXTR",
        0x719F387E: "samus_dark_morph_trim.TXTR",
        0xD0041B18: "samus_dark_morph_trim_2.TXTR",
        0x59C822A0: "samus_dark_spider.TXTR",
        0xF85301C6: "samus_dark_spider_emissive.TXTR",
        0x8CF8043C: "samus_dark_spider_polish.TXTR",
        0x21722E06: "samus_dark_spider_glass.TXTR",
        0x459769C7: "samus_dark_spider_glass_polish.TXTR",
        0x7F5781D8: "samus_dark_low_res_armor.TXTR",
        0xFF45E6C4: "samus_dark_low_res_armor_emissive.TXTR",
        0x091ACC33: "samus_dark_low_res_backpack.TXTR",
        0xDD1473FC: "samus_dark_low_res_armor_metallic.TXTR",
        0x2F566CEC: "samus_morph_2_3_metallic.TXTR",
        0x80A7CF0D: "samus_dark_left_arm_reflective.TXTR",
        0xD31B3FB2: "samus_dark_left_arm_trim.TXTR",
        0xB6728B45: "samus_dark_left_arm_trim_2.TXTR",
        0xB34CE6A0: "samus_dark_mini_emissive.TXTR",
        0x587282CC: "samus_grapple_gear.TXTR",
        0x1BA9033F: "samus_grapple_gear_metallic.TXTR",
    },
    "light": {
        0xCB737809: "samus_light_visor_core_on.TXTR",
        0xF5E3D9FF: "samus_light_visor_core_off.TXTR",
        0x0B7D7395: "samus_light_visor_core_emissive.TXTR",
        0x8048F092: "samus_light_visor_streaks.TXTR",
        0xADA9C079: "samus_light_core_beam.TXTR",
        0xC2B83ED1: "samus_light_core_beam_pattern.TXTR",
        0x5B3271CA: "samus_light_armor.TXTR",
        0xC35540DE: "samus_light_armor_metallic.TXTR",
        0x091A32D6: "samus_light_morph_shell.TXTR",
        0xC6A37961: "samus_light_morph_emissive.TXTR",
        0x0662A1C7: "samus_light_morph_metallic.TXTR",
        0x8A598DD2: "samus_light_low_res_armor.TXTR",
        0x95E79836: "samus_light_low_res_armor_emissive.TXTR",
        0x0C32C6DA: "samus_light_left_arm.TXTR",
        0xC9B164A1: "samus_light_left_arm_trim.TXTR",
        0x087D0789: "samus_light_left_arm_trim_2.TXTR",
        0xA240A5D3: "samus_light_mini_core_off.TXTR",
        0xAA2D0CCF: "samus_light_mini_emissive.TXTR",
    },
}
