# Generated by asset_id_files.py

AGON_WASTES_MLVL = 0x42B935E4
GREAT_TEMPLE_MLVL = 0x863FCD72
SANCTUARY_FORTRESS_MLVL = 0x1BAA96C2
TEMPLE_GROUNDS_MLVL = 0x3BFA3EFF
TORVUS_BOG_MLVL = 0x3DFD2249

NAME_TO_ID_MLVL = {
    "Agon Wastes": 0x42B935E4,
    "Great Temple": 0x863FCD72,
    "Sanctuary Fortress": 0x1BAA96C2,
    "Temple Grounds": 0x3BFA3EFF,
    "Torvus Bog": 0x3DFD2249,
}
# Generated by asset_id_files.py

AGON_WASTES_MAPW = 0x38DBF6A5
GREAT_TEMPLE_MAPW = 0xFC5D0E33
SANCTUARY_FORTRESS_MAPW = 0x61C85583
TEMPLE_GROUNDS_MAPW = 0x4198FDBE
TORVUS_BOG_MAPW = 0x479FE108

NAME_TO_ID_MAPW = {
    "Agon Wastes": 0x38DBF6A5,
    "Great Temple": 0xFC5D0E33,
    "Sanctuary Fortress": 0x61C85583,
    "Temple Grounds": 0x4198FDBE,
    "Torvus Bog": 0x479FE108,
}

_DEDICATED_FILES = {
    "Agon Wastes": ".agon_wastes",
    "Great Temple": ".great_temple",
    "Sanctuary Fortress": ".sanctuary_fortress",
    "Temple Grounds": ".temple_grounds",
    "Torvus Bog": ".torvus_bog",
}


def load_dedicated_file(world_name: str):
    import importlib
    return importlib.import_module(
        _DEDICATED_FILES[world_name],
        ".".join(__name__.split(".")[:-1]),
    )
