# Generated by asset_id_files.py

SCANDUMMY_MREA = 0x131C3388
ABANDONED_BASE_MREA = 0xC6F4E0C2
ACCURSED_LAKE_MREA = 0x9FD196DF
AGON_TRANSPORT_ACCESS_MREA = 0xA391C9AB
BASE_ACCESS_MREA = 0x686F5A1B
COLLAPSED_TUNNEL_MREA = 0x5B92D146
COMMAND_CHAMBER_MREA = 0xD627000B
COMMUNICATION_AREA_MREA = 0x635E8DA1
DEFILED_SHRINE_MREA = 0x16E116B4
DYNAMO_CHAMBER_MREA = 0xB4C067A7
FORTRESS_TRANSPORT_ACCESS_MREA = 0x70E5E6DD
GFMC_COMPOUND_MREA = 0x57757AD5
GATEWAY_ACCESS_MREA = 0x84324C98
GRAND_WINDCHAMBER_MREA = 0xAD70917D
HALL_OF_EYES_MREA = 0x476BA84C
HALL_OF_HONORED_DEAD_MREA = 0xB8B34634
HIVE_ACCESS_TUNNEL_MREA = 0xB1140C24
HIVE_CHAMBER_A_MREA = 0x50B372A5
HIVE_CHAMBER_B_MREA = 0x1D7BD3AE
HIVE_CHAMBER_C_MREA = 0xFB843824
HIVE_SAVE_STATION_MREA = 0x1461DC2F
HIVE_STORAGE_MREA = 0x6367D577
HIVE_TRANSPORT_AREA_MREA = 0x941F873A
HIVE_TUNNEL_MREA = 0x1582EC4A
INDUSTRIAL_SITE_MREA = 0x62AC8AC4
ING_RELIQUARY_MREA = 0x749E82E3
ING_WINDCHAMBER_MREA = 0xCDEF2BF1
LAKE_ACCESS_MREA = 0x688AB8AE
LANDING_SITE_MREA = 0x62B0D67D
MEETING_GROUNDS_MREA = 0x9B5EFA75
PATH_OF_EYES_MREA = 0xEE4732BE
PATH_OF_HONOR_MREA = 0x7B4D31DB
PHAZON_GROUNDS_MREA = 0x645EF243
PHAZON_PIT_MREA = 0x1E332000
PLAIN_OF_DARK_WORSHIP_MREA = 0x0405EBA4
PORTAL_SITE_MREA = 0xDA37FF97
PROFANE_PATH_MREA = 0x64E640D6
RELIQUARY_ACCESS_MREA = 0x8540CAD4
RELIQUARY_GROUNDS_MREA = 0xFC8FC0A4
SACRED_BRIDGE_MREA = 0xBABCDB22
SACRED_PATH_MREA = 0xC23CFFBD
SERVICE_ACCESS_MREA = 0x9FB7503C
SHRINE_ACCESS_MREA = 0x1F1D07DF
SKY_TEMPLE_GATEWAY_MREA = 0x87D35EE4
STORAGE_CAVERN_A_MREA = 0x3800CF82
STORAGE_CAVERN_B_MREA = 0xBE94BD2C
TEMPLE_ASSEMBLY_SITE_MREA = 0x4B4E5911
TEMPLE_TRANSPORT_A_MREA = 0x503A0640
TEMPLE_TRANSPORT_B_MREA = 0x4CC37F4A
TEMPLE_TRANSPORT_C_MREA = 0xADED752E
TORVUS_TRANSPORT_ACCESS_MREA = 0xA8391EAD
TRANSPORT_TO_AGON_WASTES_MREA = 0x62FF94EE
TRANSPORT_TO_SANCTUARY_FORTRESS_MREA = 0xCDF7686B
TRANSPORT_TO_TORVUS_BOG_MREA = 0xAC32F338
TROOPER_SECURITY_STATION_MREA = 0x55EE6DC3
WAR_RITUAL_GROUNDS_MREA = 0xAA77EAAD
WINDCHAMBER_GATEWAY_MREA = 0x75318D5E
WINDCHAMBER_TUNNEL_MREA = 0x9A633BBF
GAME_END_PART1_MREA = 0x1ED8D8B1
GAME_END_PART2_MREA = 0x984CAA1F
GAME_END_PART3_MREA = 0x531079BA
GAME_END_PART4_MREA = 0x4E154902
GAME_END_PART5_MREA = 0x85499AA7

NAME_TO_ID_MREA = {
    "00_scandummy": 0x131C3388,
    "Abandoned Base": 0xC6F4E0C2,
    "Accursed Lake": 0x9FD196DF,
    "Agon Transport Access": 0xA391C9AB,
    "Base Access": 0x686F5A1B,
    "Collapsed Tunnel": 0x5B92D146,
    "Command Chamber": 0xD627000B,
    "Communication Area": 0x635E8DA1,
    "Defiled Shrine": 0x16E116B4,
    "Dynamo Chamber": 0xB4C067A7,
    "Fortress Transport Access": 0x70E5E6DD,
    "GFMC Compound": 0x57757AD5,
    "Gateway Access": 0x84324C98,
    "Grand Windchamber": 0xAD70917D,
    "Hall of Eyes": 0x476BA84C,
    "Hall of Honored Dead": 0xB8B34634,
    "Hive Access Tunnel": 0xB1140C24,
    "Hive Chamber A": 0x50B372A5,
    "Hive Chamber B": 0x1D7BD3AE,
    "Hive Chamber C": 0xFB843824,
    "Hive Save Station": 0x1461DC2F,
    "Hive Storage": 0x6367D577,
    "Hive Transport Area": 0x941F873A,
    "Hive Tunnel": 0x1582EC4A,
    "Industrial Site": 0x62AC8AC4,
    "Ing Reliquary": 0x749E82E3,
    "Ing Windchamber": 0xCDEF2BF1,
    "Lake Access": 0x688AB8AE,
    "Landing Site": 0x62B0D67D,
    "Meeting Grounds": 0x9B5EFA75,
    "Path of Eyes": 0xEE4732BE,
    "Path of Honor": 0x7B4D31DB,
    "Phazon Grounds": 0x645EF243,
    "Phazon Pit": 0x1E332000,
    "Plain of Dark Worship": 0x0405EBA4,
    "Portal Site": 0xDA37FF97,
    "Profane Path": 0x64E640D6,
    "Reliquary Access": 0x8540CAD4,
    "Reliquary Grounds": 0xFC8FC0A4,
    "Sacred Bridge": 0xBABCDB22,
    "Sacred Path": 0xC23CFFBD,
    "Service Access": 0x9FB7503C,
    "Shrine Access": 0x1F1D07DF,
    "Sky Temple Gateway": 0x87D35EE4,
    "Storage Cavern A": 0x3800CF82,
    "Storage Cavern B": 0xBE94BD2C,
    "Temple Assembly Site": 0x4B4E5911,
    "Temple Transport A": 0x503A0640,
    "Temple Transport B": 0x4CC37F4A,
    "Temple Transport C": 0xADED752E,
    "Torvus Transport Access": 0xA8391EAD,
    "Transport to Agon Wastes": 0x62FF94EE,
    "Transport to Sanctuary Fortress": 0xCDF7686B,
    "Transport to Torvus Bog": 0xAC32F338,
    "Trooper Security Station": 0x55EE6DC3,
    "War Ritual Grounds": 0xAA77EAAD,
    "Windchamber Gateway": 0x75318D5E,
    "Windchamber Tunnel": 0x9A633BBF,
    "game_end_part1": 0x1ED8D8B1,
    "game_end_part2": 0x984CAA1F,
    "game_end_part3": 0x531079BA,
    "game_end_part4": 0x4E154902,
    "game_end_part5": 0x85499AA7,
}
# Generated by asset_id_files.py

SCANDUMMY_MAPA = 0x3AC9C8B5
ABANDONED_BASE_MAPA = 0xEF211BFF
ACCURSED_LAKE_MAPA = 0xB6046DE2
AGON_TRANSPORT_ACCESS_MAPA = 0x8A443296
BASE_ACCESS_MAPA = 0x41BAA126
COLLAPSED_TUNNEL_MAPA = 0x72472A7B
COMMAND_CHAMBER_MAPA = 0xFFF2FB36
COMMUNICATION_AREA_MAPA = 0x4A8B769C
DEFILED_SHRINE_MAPA = 0x3F34ED89
DYNAMO_CHAMBER_MAPA = 0x9D159C9A
FORTRESS_TRANSPORT_ACCESS_MAPA = 0x59301DE0
GFMC_COMPOUND_MAPA = 0x7EA081E8
GATEWAY_ACCESS_MAPA = 0xADE7B7A5
GRAND_WINDCHAMBER_MAPA = 0x84A56A40
HALL_OF_EYES_MAPA = 0x6EBE5371
HALL_OF_HONORED_DEAD_MAPA = 0x9166BD09
HIVE_ACCESS_TUNNEL_MAPA = 0x98C1F719
HIVE_CHAMBER_A_MAPA = 0x79668998
HIVE_CHAMBER_B_MAPA = 0x34AE2893
HIVE_CHAMBER_C_MAPA = 0xD251C319
HIVE_SAVE_STATION_MAPA = 0x3DB42712
HIVE_STORAGE_MAPA = 0x4AB22E4A
HIVE_TRANSPORT_AREA_MAPA = 0xBDCA7C07
HIVE_TUNNEL_MAPA = 0x3C571777
INDUSTRIAL_SITE_MAPA = 0x4B7971F9
ING_RELIQUARY_MAPA = 0x5D4B79DE
ING_WINDCHAMBER_MAPA = 0xE43AD0CC
LAKE_ACCESS_MAPA = 0x415F4393
LANDING_SITE_MAPA = 0x4B652D40
MEETING_GROUNDS_MAPA = 0xB28B0148
PATH_OF_EYES_MAPA = 0xC792C983
PATH_OF_HONOR_MAPA = 0x5298CAE6
PHAZON_GROUNDS_MAPA = 0x4D8B097E
PHAZON_PIT_MAPA = 0x37E6DB3D
PLAIN_OF_DARK_WORSHIP_MAPA = 0x2DD01099
PORTAL_SITE_MAPA = 0xF3E204AA
PROFANE_PATH_MAPA = 0x4D33BBEB
RELIQUARY_ACCESS_MAPA = 0xAC9531E9
RELIQUARY_GROUNDS_MAPA = 0xD55A3B99
SACRED_BRIDGE_MAPA = 0x9369201F
SACRED_PATH_MAPA = 0xEBE90480
SERVICE_ACCESS_MAPA = 0xB662AB01
SHRINE_ACCESS_MAPA = 0x36C8FCE2
SKY_TEMPLE_GATEWAY_MAPA = 0xAE06A5D9
STORAGE_CAVERN_A_MAPA = 0x11D534BF
STORAGE_CAVERN_B_MAPA = 0x97414611
TEMPLE_ASSEMBLY_SITE_MAPA = 0x629BA22C
TEMPLE_TRANSPORT_A_MAPA = 0x79EFFD7D
TEMPLE_TRANSPORT_B_MAPA = 0x65168477
TEMPLE_TRANSPORT_C_MAPA = 0x84388E13
TORVUS_TRANSPORT_ACCESS_MAPA = 0x81ECE590
TRANSPORT_TO_AGON_WASTES_MAPA = 0x4B2A6FD3
TRANSPORT_TO_SANCTUARY_FORTRESS_MAPA = 0xE4229356
TRANSPORT_TO_TORVUS_BOG_MAPA = 0x85E70805
TROOPER_SECURITY_STATION_MAPA = 0x7C3B96FE
WAR_RITUAL_GROUNDS_MAPA = 0x83A21190
WINDCHAMBER_GATEWAY_MAPA = 0x5CE47663
WINDCHAMBER_TUNNEL_MAPA = 0xB3B6C082
GAME_END_PART1_MAPA = 0x370D238C
GAME_END_PART2_MAPA = 0xB1995122
GAME_END_PART3_MAPA = 0x7AC58287
GAME_END_PART4_MAPA = 0x67C0B23F
GAME_END_PART5_MAPA = 0xAC9C619A

NAME_TO_ID_MAPA = {
    "00_scandummy": 0x3AC9C8B5,
    "Abandoned Base": 0xEF211BFF,
    "Accursed Lake": 0xB6046DE2,
    "Agon Transport Access": 0x8A443296,
    "Base Access": 0x41BAA126,
    "Collapsed Tunnel": 0x72472A7B,
    "Command Chamber": 0xFFF2FB36,
    "Communication Area": 0x4A8B769C,
    "Defiled Shrine": 0x3F34ED89,
    "Dynamo Chamber": 0x9D159C9A,
    "Fortress Transport Access": 0x59301DE0,
    "GFMC Compound": 0x7EA081E8,
    "Gateway Access": 0xADE7B7A5,
    "Grand Windchamber": 0x84A56A40,
    "Hall of Eyes": 0x6EBE5371,
    "Hall of Honored Dead": 0x9166BD09,
    "Hive Access Tunnel": 0x98C1F719,
    "Hive Chamber A": 0x79668998,
    "Hive Chamber B": 0x34AE2893,
    "Hive Chamber C": 0xD251C319,
    "Hive Save Station": 0x3DB42712,
    "Hive Storage": 0x4AB22E4A,
    "Hive Transport Area": 0xBDCA7C07,
    "Hive Tunnel": 0x3C571777,
    "Industrial Site": 0x4B7971F9,
    "Ing Reliquary": 0x5D4B79DE,
    "Ing Windchamber": 0xE43AD0CC,
    "Lake Access": 0x415F4393,
    "Landing Site": 0x4B652D40,
    "Meeting Grounds": 0xB28B0148,
    "Path of Eyes": 0xC792C983,
    "Path of Honor": 0x5298CAE6,
    "Phazon Grounds": 0x4D8B097E,
    "Phazon Pit": 0x37E6DB3D,
    "Plain of Dark Worship": 0x2DD01099,
    "Portal Site": 0xF3E204AA,
    "Profane Path": 0x4D33BBEB,
    "Reliquary Access": 0xAC9531E9,
    "Reliquary Grounds": 0xD55A3B99,
    "Sacred Bridge": 0x9369201F,
    "Sacred Path": 0xEBE90480,
    "Service Access": 0xB662AB01,
    "Shrine Access": 0x36C8FCE2,
    "Sky Temple Gateway": 0xAE06A5D9,
    "Storage Cavern A": 0x11D534BF,
    "Storage Cavern B": 0x97414611,
    "Temple Assembly Site": 0x629BA22C,
    "Temple Transport A": 0x79EFFD7D,
    "Temple Transport B": 0x65168477,
    "Temple Transport C": 0x84388E13,
    "Torvus Transport Access": 0x81ECE590,
    "Transport to Agon Wastes": 0x4B2A6FD3,
    "Transport to Sanctuary Fortress": 0xE4229356,
    "Transport to Torvus Bog": 0x85E70805,
    "Trooper Security Station": 0x7C3B96FE,
    "War Ritual Grounds": 0x83A21190,
    "Windchamber Gateway": 0x5CE47663,
    "Windchamber Tunnel": 0xB3B6C082,
    "game_end_part1": 0x370D238C,
    "game_end_part2": 0xB1995122,
    "game_end_part3": 0x7AC58287,
    "game_end_part4": 0x67C0B23F,
    "game_end_part5": 0xAC9C619A,
}
# Generated by asset_id_files.py

SCANDUMMY_INTERNAL_ID = 0x775664A5
ABANDONED_BASE_INTERNAL_ID = 0x89D924A7
ACCURSED_LAKE_INTERNAL_ID = 0x012F9639
AGON_TRANSPORT_ACCESS_INTERNAL_ID = 0x650909ED
BASE_ACCESS_INTERNAL_ID = 0x07CE0C72
COLLAPSED_TUNNEL_INTERNAL_ID = 0x1671BCCE
COMMAND_CHAMBER_INTERNAL_ID = 0xCFB06832
COMMUNICATION_AREA_INTERNAL_ID = 0xDCEC348B
DEFILED_SHRINE_INTERNAL_ID = 0xB23C2110
DYNAMO_CHAMBER_INTERNAL_ID = 0x600D7227
FORTRESS_TRANSPORT_ACCESS_INTERNAL_ID = 0xF080D688
GFMC_COMPOUND_INTERNAL_ID = 0xEAA44A69
GATEWAY_ACCESS_INTERNAL_ID = 0xBA85FBF7
GRAND_WINDCHAMBER_INTERNAL_ID = 0xDD711FE2
HALL_OF_EYES_INTERNAL_ID = 0x11F7FAE1
HALL_OF_HONORED_DEAD_INTERNAL_ID = 0x1DA26BFF
HIVE_ACCESS_TUNNEL_INTERNAL_ID = 0x8CF4EFF5
HIVE_CHAMBER_A_INTERNAL_ID = 0xB168BFA2
HIVE_CHAMBER_B_INTERNAL_ID = 0xE5F82542
HIVE_CHAMBER_C_INTERNAL_ID = 0x3AE18F4C
HIVE_SAVE_STATION_INTERNAL_ID = 0x298A46B7
HIVE_STORAGE_INTERNAL_ID = 0xBB04ED2C
HIVE_TRANSPORT_AREA_INTERNAL_ID = 0x847E2584
HIVE_TUNNEL_INTERNAL_ID = 0xBA47CB1F
INDUSTRIAL_SITE_INTERNAL_ID = 0xFBF7026A
ING_RELIQUARY_INTERNAL_ID = 0x4A3FAEBF
ING_WINDCHAMBER_INTERNAL_ID = 0x8FDF7C49
LAKE_ACCESS_INTERNAL_ID = 0x02C294BE
LANDING_SITE_INTERNAL_ID = 0x469F86A0
MEETING_GROUNDS_INTERNAL_ID = 0x263B762F
PATH_OF_EYES_INTERNAL_ID = 0xA1E4608C
PATH_OF_HONOR_INTERNAL_ID = 0xF202EB6D
PHAZON_GROUNDS_INTERNAL_ID = 0x7229A05E
PHAZON_PIT_INTERNAL_ID = 0xB65538F6
PLAIN_OF_DARK_WORSHIP_INTERNAL_ID = 0xF7602CF0
PORTAL_SITE_INTERNAL_ID = 0x140FDC57
PROFANE_PATH_INTERNAL_ID = 0xE90B6B28
RELIQUARY_ACCESS_INTERNAL_ID = 0x0044D8D8
RELIQUARY_GROUNDS_INTERNAL_ID = 0x4136D070
SACRED_BRIDGE_INTERNAL_ID = 0x8E76D210
SACRED_PATH_INTERNAL_ID = 0xC328BC32
SERVICE_ACCESS_INTERNAL_ID = 0x86FC1861
SHRINE_ACCESS_INTERNAL_ID = 0xB94091A2
SKY_TEMPLE_GATEWAY_INTERNAL_ID = 0x16828ED5
STORAGE_CAVERN_A_INTERNAL_ID = 0xB09B5078
STORAGE_CAVERN_B_INTERNAL_ID = 0xAF258380
TEMPLE_ASSEMBLY_SITE_INTERNAL_ID = 0x163904FE
TEMPLE_TRANSPORT_A_INTERNAL_ID = 0x14F3812B
TEMPLE_TRANSPORT_B_INTERNAL_ID = 0x1375C704
TEMPLE_TRANSPORT_C_INTERNAL_ID = 0x8B72A9DA
TORVUS_TRANSPORT_ACCESS_INTERNAL_ID = 0x678B3408
TRANSPORT_TO_AGON_WASTES_INTERNAL_ID = 0xFA35B470
TRANSPORT_TO_SANCTUARY_FORTRESS_INTERNAL_ID = 0x328E85F6
TRANSPORT_TO_TORVUS_BOG_INTERNAL_ID = 0x287DEF75
TROOPER_SECURITY_STATION_INTERNAL_ID = 0xF80A1CF9
WAR_RITUAL_GROUNDS_INTERNAL_ID = 0x4767E520
WINDCHAMBER_GATEWAY_INTERNAL_ID = 0x1C794B5A
WINDCHAMBER_TUNNEL_INTERNAL_ID = 0x6A0585B3
GAME_END_PART1_INTERNAL_ID = 0x752B2850
GAME_END_PART2_INTERNAL_ID = 0x9D221F4A
GAME_END_PART3_INTERNAL_ID = 0xC5250DBC
GAME_END_PART4_INTERNAL_ID = 0x9641773F
GAME_END_PART5_INTERNAL_ID = 0xCE4665C9

NAME_TO_ID_INTERNAL_ID = {
    "00_scandummy": 0x775664A5,
    "Abandoned Base": 0x89D924A7,
    "Accursed Lake": 0x012F9639,
    "Agon Transport Access": 0x650909ED,
    "Base Access": 0x07CE0C72,
    "Collapsed Tunnel": 0x1671BCCE,
    "Command Chamber": 0xCFB06832,
    "Communication Area": 0xDCEC348B,
    "Defiled Shrine": 0xB23C2110,
    "Dynamo Chamber": 0x600D7227,
    "Fortress Transport Access": 0xF080D688,
    "GFMC Compound": 0xEAA44A69,
    "Gateway Access": 0xBA85FBF7,
    "Grand Windchamber": 0xDD711FE2,
    "Hall of Eyes": 0x11F7FAE1,
    "Hall of Honored Dead": 0x1DA26BFF,
    "Hive Access Tunnel": 0x8CF4EFF5,
    "Hive Chamber A": 0xB168BFA2,
    "Hive Chamber B": 0xE5F82542,
    "Hive Chamber C": 0x3AE18F4C,
    "Hive Save Station": 0x298A46B7,
    "Hive Storage": 0xBB04ED2C,
    "Hive Transport Area": 0x847E2584,
    "Hive Tunnel": 0xBA47CB1F,
    "Industrial Site": 0xFBF7026A,
    "Ing Reliquary": 0x4A3FAEBF,
    "Ing Windchamber": 0x8FDF7C49,
    "Lake Access": 0x02C294BE,
    "Landing Site": 0x469F86A0,
    "Meeting Grounds": 0x263B762F,
    "Path of Eyes": 0xA1E4608C,
    "Path of Honor": 0xF202EB6D,
    "Phazon Grounds": 0x7229A05E,
    "Phazon Pit": 0xB65538F6,
    "Plain of Dark Worship": 0xF7602CF0,
    "Portal Site": 0x140FDC57,
    "Profane Path": 0xE90B6B28,
    "Reliquary Access": 0x0044D8D8,
    "Reliquary Grounds": 0x4136D070,
    "Sacred Bridge": 0x8E76D210,
    "Sacred Path": 0xC328BC32,
    "Service Access": 0x86FC1861,
    "Shrine Access": 0xB94091A2,
    "Sky Temple Gateway": 0x16828ED5,
    "Storage Cavern A": 0xB09B5078,
    "Storage Cavern B": 0xAF258380,
    "Temple Assembly Site": 0x163904FE,
    "Temple Transport A": 0x14F3812B,
    "Temple Transport B": 0x1375C704,
    "Temple Transport C": 0x8B72A9DA,
    "Torvus Transport Access": 0x678B3408,
    "Transport to Agon Wastes": 0xFA35B470,
    "Transport to Sanctuary Fortress": 0x328E85F6,
    "Transport to Torvus Bog": 0x287DEF75,
    "Trooper Security Station": 0xF80A1CF9,
    "War Ritual Grounds": 0x4767E520,
    "Windchamber Gateway": 0x1C794B5A,
    "Windchamber Tunnel": 0x6A0585B3,
    "game_end_part1": 0x752B2850,
    "game_end_part2": 0x9D221F4A,
    "game_end_part3": 0xC5250DBC,
    "game_end_part4": 0x9641773F,
    "game_end_part5": 0xCE4665C9,
}

DOCK_NAMES = {
    "00_scandummy": {
        "VirtualNorth": 0,
    },
    "Abandoned Base": {
        "East": 0,
        "North": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Accursed Lake": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Agon Transport Access": {
        "West": 0,
        "South": 1,
    },
    "Base Access": {
        "Docks_VirtualNorth": 0,
        "South": 1,
        "West": 2,
    },
    "Collapsed Tunnel": {
        "A__South": 0,
        "A__North1": 1,
    },
    "Command Chamber": {
        "West2": 0,
        "East": 1,
    },
    "Communication Area": {
        "South1": 0,
        "North": 1,
        "South11": 2,
    },
    "Defiled Shrine": {
        "North": 0,
        "East1": 1,
        "VirtualWest": 2,
    },
    "Dynamo Chamber": {
        "North": 0,
        "South": 1,
    },
    "Fortress Transport Access": {
        "West": 0,
        "South": 1,
    },
    "GFMC Compound": {
        "East": 0,
        "North": 1,
        "WestTop": 2,
        "West": 3,
    },
    "Gateway Access": {
        "West": 0,
        "WestUpper": 1,
        "NorthUpper": 2,
        "North": 3,
    },
    "Grand Windchamber": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Hall of Eyes": {
        "Docks_VirtualNorth": 0,
        "South": 1,
        "West": 2,
    },
    "Hall of Honored Dead": {
        "South_Morphball": 0,
        "South": 1,
        "VirtualNorth": 2,
    },
    "Hive Access Tunnel": {
        "East": 0,
        "West": 1,
        "Floor": 2,
    },
    "Hive Chamber A": {
        "Ceiling": 0,
        "East": 1,
    },
    "Hive Chamber B": {
        "South": 0,
        "North": 1,
        "VirtualDock": 2,
    },
    "Hive Chamber C": {
        "blue_01_Temple_Hive_1_4_West_BigDoor": 0,
        "South": 1,
        "North1": 2,
    },
    "Hive Save Station": {
        "South": 0,
    },
    "Hive Storage": {
        "West": 0,
        "North1": 1,
    },
    "Hive Transport Area": {
        "East_Upper": 0,
        "group35_blue_01_Temple_Hive_1_4_East_BigDoor": 1,
        "West": 2,
    },
    "Hive Tunnel": {
        "West": 0,
        "East1": 1,
    },
    "Industrial Site": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Ing Reliquary": {
        "North_Top": 0,
    },
    "Ing Windchamber": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Lake Access": {
        "A__South": 0,
        "A__North1": 1,
    },
    "Landing Site": {
        "North": 0,
        "East1": 1,
    },
    "Meeting Grounds": {
        "North": 0,
        "East1": 1,
        "EastTop": 2,
        "EastBottom": 3,
    },
    "Path of Eyes": {
        "East": 0,
        "North": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Path of Honor": {
        "West": 0,
        "WestUpper": 1,
        "NorthUpper": 2,
        "North": 3,
    },
    "Phazon Grounds": {
        "East": 0,
        "North": 1,
        "WestTop": 2,
        "West": 3,
    },
    "Phazon Pit": {
        "East": 0,
        "South": 1,
    },
    "Plain of Dark Worship": {
        "South": 0,
        "North": 1,
        "South1": 2,
        "VirtualNorth": 3,
    },
    "Portal Site": {
        "South": 0,
        "North": 1,
        "VirtualDock": 2,
    },
    "Profane Path": {
        "North": 0,
        "VirtualNorth1": 1,
    },
    "Reliquary Access": {
        "South": 0,
        "West": 1,
    },
    "Reliquary Grounds": {
        "South_Top": 0,
        "North": 1,
        "South_Bottom": 2,
    },
    "Sacred Bridge": {
        "East": 0,
        "South": 1,
    },
    "Sacred Path": {
        "South1": 0,
        "North": 1,
        "VirtualNorth1": 2,
    },
    "Service Access": {
        "South": 0,
        "East": 1,
        "West": 2,
        "East1": 3,
        "West11": 4,
    },
    "Shrine Access": {
        "South": 0,
        "East": 1,
        "West": 2,
        "East1": 3,
        "West11": 4,
    },
    "Sky Temple Gateway": {
        "South": 0,
        "VirtualNorth": 1,
        "Cinema_Dock": 2,
    },
    "Storage Cavern A": {
        "North_Top": 0,
    },
    "Storage Cavern B": {
        "North": 0,
    },
    "Temple Assembly Site": {
        "South": 0,
        "North": 1,
        "West": 2,
        "South1": 3,
        "VirtualNorth": 4,
    },
    "Temple Transport A": {
        "North": 0,
    },
    "Temple Transport B": {
        "East": 0,
    },
    "Temple Transport C": {
        "blue_0M_Temple_hall_West": 0,
    },
    "Torvus Transport Access": {
        "North": 0,
        "South": 1,
    },
    "Transport to Agon Wastes": {
        "Dock - North": 0,
    },
    "Transport to Sanctuary Fortress": {
        "East": 0,
    },
    "Transport to Torvus Bog": {
        "North": 0,
    },
    "Trooper Security Station": {
        "blue_0D_Temple_hall_South": 0,
        "blue_0D_Temple_hall_West": 1,
    },
    "War Ritual Grounds": {
        "North": 0,
        "EastTop": 1,
        "EastBottom": 2,
    },
    "Windchamber Gateway": {
        "East": 0,
        "South": 1,
    },
    "Windchamber Tunnel": {
        "South": 0,
        "East": 1,
    },
    "game_end_part1": {
        "South_Morphball": 0,
        "South": 1,
        "VirtualNorth": 2,
        "cinema_light2": 3,
        "cinema_light1": 4,
    },
    "game_end_part2": {
        "SouthLight1": 0,
        "VirtualNorth": 1,
        "North1": 2,
        "cinema_dock1": 3,
        "cinema_dock2": 4,
    },
    "game_end_part3": {
        "North": 0,
        "East1": 1,
        "cinema_dock": 2,
        "SPACEROOM": 3,
    },
    "game_end_part4": {
        "cinema_dock": 0,
        "North": 1,
    },
    "game_end_part5": {
        "cinema_dock": 0,
    },
}
